__all__ = [
    "PROPERTY_TYPE_MAP",
    "PROPERTY_IDLTYPE_MAP",
    "PROPERTYTYPE_TREAT_ELEMENT_AS_OBJECT",
    "IDLTYPE_TREAT_ELEMENT_AS_OBJECT",
    "KNOWN_EVENTS",
    "KNOWN_EVENT_NAMES",
]
    

PROPERTY_TYPE_MAP = {
    "datetime": "winrt::Windows::Foundation::DateTime",
    "timedelta": "winrt::Windows::Foundation::TimeSpan",
    "str": "winrt::hstring",
    "float": "double",
    "object": "winrt::Windows::Foundation::IInspectable",
    "list": "winrt::Windows::Foundation::Collections::IVector",
    "UUID": "GUID",
}


PROPERTY_IDLTYPE_MAP = {
    "uint8_t": "UInt8",
    "uint16_t": "UInt16",
    "uint32_t": "UInt32",
    "uint64_t": "UInt64",
    "int16_t": "Int16",
    "int32_t": "Int32",
    "int64_t": "Int64",
    "wchar_t": "Char",
    "std::wstring": "String",
    "winrt::hstring": "String",
    "float": "Single",
    "double": "Double",
    "bool": "Boolean",
    "GUID": "Guid",
    "winrt::Windows::Foundation::IInspectable": "IInspectable",
    "winrt::Windows::Foundation::DateTime": "Windows.Foundation.DateTime",
    "winrt::Windows::Foundation::TimeSpan": "Windows.Foundation.TimeSpan",
    "winrt::Windows::Foundation::Collections::IVector": "Windows.Foundation.Collections.IVector",
}

PROPERTYTYPE_TREAT_ELEMENT_AS_OBJECT = {
    "winrt::Windows::Foundation::Collections::IVector",
}

IDLTYPE_TREAT_ELEMENT_AS_OBJECT = {
    "Windows.Foundation.Collections.IVector",
}

KNOWN_EVENTS = {
    ("_:FrameworkElement", "ActualThemeChanged"): ("Microsoft.UI.Xaml.FrameworkElement", "Windows.Foundation.IInspectable"),
    ("_:FrameworkElement", "DataContextChanged"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.DataContextChangedEventArgs"),
    ("_:FrameworkElement", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.EffectiveViewportChangedEventArgs"),
    ("_:FrameworkElement", "LayoutUpdated"): ("Microsoft.UI.Xaml.FrameworkElement", "Windows.Foundation.IInspectable"),
    ("_:FrameworkElement", "Loaded"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FrameworkElement", "Loading"): ("Microsoft.UI.Xaml.FrameworkElement", "Windows.Foundation.IInspectable"),
    ("_:FrameworkElement", "SizeChanged"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.SizeChangedEventHandler"),
    ("_:FrameworkElement", "Unloaded"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FrameworkElement", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:FrameworkElement", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:FrameworkElement", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:FrameworkElement", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.BringIntoViewRequestedEventArgs"),
    ("_:FrameworkElement", "CharacterReceived"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:FrameworkElement", "ContextCanceled"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FrameworkElement", "ContextRequested"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:FrameworkElement", "DoubleTapped"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:FrameworkElement", "DragEnter"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.DragEventArgs"),
    ("_:FrameworkElement", "DragLeave"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.DragEventArgs"),
    ("_:FrameworkElement", "DragOver"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.DragEventArgs"),
    ("_:FrameworkElement", "DragStarting"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.DragStartingEventArgs"),
    ("_:FrameworkElement", "Drop"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.DragEventArgs"),
    ("_:FrameworkElement", "DropCompleted"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.DropCompletedEventArgs"),
    ("_:FrameworkElement", "GettingFocus"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:FrameworkElement", "GotFocus"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FrameworkElement", "Holding"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:FrameworkElement", "KeyDown"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FrameworkElement", "KeyUp"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FrameworkElement", "LosingFocus"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:FrameworkElement", "LostFocus"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FrameworkElement", "ManipulationCompleted"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:FrameworkElement", "ManipulationDelta"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:FrameworkElement", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:FrameworkElement", "ManipulationStarted"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:FrameworkElement", "ManipulationStarting"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:FrameworkElement", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:FrameworkElement", "PointerCanceled"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FrameworkElement", "PointerCaptureLost"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FrameworkElement", "PointerEntered"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FrameworkElement", "PointerExited"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FrameworkElement", "PointerMoved"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FrameworkElement", "PointerPressed"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FrameworkElement", "PointerReleased"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FrameworkElement", "PointerWheelChanged"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FrameworkElement", "PreviewKeyDown"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FrameworkElement", "PreviewKeyUp"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FrameworkElement", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FrameworkElement", "RightTapped"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:FrameworkElement", "Tapped"): ("Microsoft.UI.Xaml.FrameworkElement", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:UIElement", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:UIElement", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:UIElement", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:UIElement", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.BringIntoViewRequestedEventArgs"),
    ("_:UIElement", "CharacterReceived"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:UIElement", "ContextCanceled"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:UIElement", "ContextRequested"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:UIElement", "DoubleTapped"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:UIElement", "DragEnter"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.DragEventArgs"),
    ("_:UIElement", "DragLeave"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.DragEventArgs"),
    ("_:UIElement", "DragOver"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.DragEventArgs"),
    ("_:UIElement", "DragStarting"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.DragStartingEventArgs"),
    ("_:UIElement", "Drop"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.DragEventArgs"),
    ("_:UIElement", "DropCompleted"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.DropCompletedEventArgs"),
    ("_:UIElement", "GettingFocus"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:UIElement", "GotFocus"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:UIElement", "Holding"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:UIElement", "KeyDown"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:UIElement", "KeyUp"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:UIElement", "LosingFocus"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:UIElement", "LostFocus"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:UIElement", "ManipulationCompleted"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:UIElement", "ManipulationDelta"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:UIElement", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:UIElement", "ManipulationStarted"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:UIElement", "ManipulationStarting"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:UIElement", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:UIElement", "PointerCanceled"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:UIElement", "PointerCaptureLost"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:UIElement", "PointerEntered"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:UIElement", "PointerExited"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:UIElement", "PointerMoved"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:UIElement", "PointerPressed"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:UIElement", "PointerReleased"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:UIElement", "PointerWheelChanged"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:UIElement", "PreviewKeyDown"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:UIElement", "PreviewKeyUp"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:UIElement", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:UIElement", "RightTapped"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:UIElement", "Tapped"): ("Microsoft.UI.Xaml.UIElement", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Windows.Foundation.IInspectable"),
    ("_:AnnotatedScrollBar", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:AnnotatedScrollBar", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:AnnotatedScrollBar", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Windows.Foundation.IInspectable"),
    ("_:AnnotatedScrollBar", "Loaded"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AnnotatedScrollBar", "Loading"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Windows.Foundation.IInspectable"),
    ("_:AnnotatedScrollBar", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:AnnotatedScrollBar", "Unloaded"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AnnotatedScrollBar", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:AnnotatedScrollBar", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:AnnotatedScrollBar", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:AnnotatedScrollBar", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:AnnotatedScrollBar", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AnnotatedScrollBar", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:AnnotatedScrollBar", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "DragEnter"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AnnotatedScrollBar", "DragLeave"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AnnotatedScrollBar", "DragOver"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AnnotatedScrollBar", "DragStarting"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:AnnotatedScrollBar", "Drop"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AnnotatedScrollBar", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:AnnotatedScrollBar", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:AnnotatedScrollBar", "GotFocus"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AnnotatedScrollBar", "Holding"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:AnnotatedScrollBar", "KeyDown"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "KeyUp"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:AnnotatedScrollBar", "LostFocus"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AnnotatedScrollBar", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:AnnotatedScrollBar", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "PointerExited"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AnnotatedScrollBar", "RightTapped"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "Tapped"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:AnnotatedScrollBar", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:AnnotatedScrollBar", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:AnnotatedScrollBar", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.AnnotatedScrollBar", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:AppBar", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.AppBar", "Windows.Foundation.IInspectable"),
    ("_:AppBar", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:AppBar", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:AppBar", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.AppBar", "Windows.Foundation.IInspectable"),
    ("_:AppBar", "Loaded"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBar", "Loading"): ("Microsoft.UI.Xaml.Controls.AppBar", "Windows.Foundation.IInspectable"),
    ("_:AppBar", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:AppBar", "Unloaded"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBar", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:AppBar", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:AppBar", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:AppBar", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:AppBar", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:AppBar", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBar", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:AppBar", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:AppBar", "DragEnter"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBar", "DragLeave"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBar", "DragOver"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBar", "DragStarting"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:AppBar", "Drop"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBar", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:AppBar", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:AppBar", "GotFocus"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBar", "Holding"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:AppBar", "KeyDown"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBar", "KeyUp"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBar", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:AppBar", "LostFocus"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBar", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:AppBar", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:AppBar", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:AppBar", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:AppBar", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:AppBar", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:AppBar", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBar", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBar", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBar", "PointerExited"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBar", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBar", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBar", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBar", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBar", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBar", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBar", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBar", "RightTapped"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:AppBar", "Tapped"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:AppBar", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:AppBar", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:AppBar", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.AppBar", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:AppBarButton", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Windows.Foundation.IInspectable"),
    ("_:AppBarButton", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:AppBarButton", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:AppBarButton", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Windows.Foundation.IInspectable"),
    ("_:AppBarButton", "Loaded"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarButton", "Loading"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Windows.Foundation.IInspectable"),
    ("_:AppBarButton", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:AppBarButton", "Unloaded"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarButton", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:AppBarButton", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:AppBarButton", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:AppBarButton", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:AppBarButton", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:AppBarButton", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarButton", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:AppBarButton", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:AppBarButton", "DragEnter"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBarButton", "DragLeave"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBarButton", "DragOver"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBarButton", "DragStarting"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:AppBarButton", "Drop"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBarButton", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:AppBarButton", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:AppBarButton", "GotFocus"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarButton", "Holding"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:AppBarButton", "KeyDown"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBarButton", "KeyUp"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBarButton", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:AppBarButton", "LostFocus"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarButton", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:AppBarButton", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:AppBarButton", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:AppBarButton", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:AppBarButton", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:AppBarButton", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:AppBarButton", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarButton", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarButton", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarButton", "PointerExited"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarButton", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarButton", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarButton", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarButton", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarButton", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBarButton", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBarButton", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarButton", "RightTapped"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:AppBarButton", "Tapped"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:AppBarButton", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:AppBarButton", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:AppBarButton", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:AppBarButton", "Click"): ("Microsoft.UI.Xaml.Controls.AppBarButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarToggleButton", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Windows.Foundation.IInspectable"),
    ("_:AppBarToggleButton", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:AppBarToggleButton", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:AppBarToggleButton", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Windows.Foundation.IInspectable"),
    ("_:AppBarToggleButton", "Loaded"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarToggleButton", "Loading"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Windows.Foundation.IInspectable"),
    ("_:AppBarToggleButton", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:AppBarToggleButton", "Unloaded"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarToggleButton", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:AppBarToggleButton", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:AppBarToggleButton", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:AppBarToggleButton", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:AppBarToggleButton", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:AppBarToggleButton", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarToggleButton", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:AppBarToggleButton", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:AppBarToggleButton", "DragEnter"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBarToggleButton", "DragLeave"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBarToggleButton", "DragOver"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBarToggleButton", "DragStarting"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:AppBarToggleButton", "Drop"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:AppBarToggleButton", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:AppBarToggleButton", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:AppBarToggleButton", "GotFocus"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarToggleButton", "Holding"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:AppBarToggleButton", "KeyDown"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBarToggleButton", "KeyUp"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBarToggleButton", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:AppBarToggleButton", "LostFocus"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarToggleButton", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:AppBarToggleButton", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:AppBarToggleButton", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:AppBarToggleButton", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:AppBarToggleButton", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:AppBarToggleButton", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:AppBarToggleButton", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarToggleButton", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarToggleButton", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarToggleButton", "PointerExited"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarToggleButton", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarToggleButton", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarToggleButton", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarToggleButton", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:AppBarToggleButton", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBarToggleButton", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:AppBarToggleButton", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarToggleButton", "RightTapped"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:AppBarToggleButton", "Tapped"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:AppBarToggleButton", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:AppBarToggleButton", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:AppBarToggleButton", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:AppBarToggleButton", "Click"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarToggleButton", "Checked"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarToggleButton", "Indeterminate"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:AppBarToggleButton", "Unchecked"): ("Microsoft.UI.Xaml.Controls.AppBarToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Border", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Border", "Windows.Foundation.IInspectable"),
    ("_:Border", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Border", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Border", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Border", "Windows.Foundation.IInspectable"),
    ("_:Border", "Loaded"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Border", "Loading"): ("Microsoft.UI.Xaml.Controls.Border", "Windows.Foundation.IInspectable"),
    ("_:Border", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Border", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Border", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Border", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Border", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Border", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Border", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Border", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Border", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Border", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Border", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Border", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Border", "DragOver"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Border", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Border", "Drop"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Border", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Border", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Border", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Border", "Holding"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Border", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Border", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Border", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Border", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Border", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Border", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Border", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Border", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Border", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Border", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Border", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Border", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Border", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Border", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Border", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Border", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Border", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Border", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Border", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Border", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Border", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Border", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Border", "Tapped"): ("Microsoft.UI.Xaml.Controls.Border", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:BreadcrumbBar", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Windows.Foundation.IInspectable"),
    ("_:BreadcrumbBar", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:BreadcrumbBar", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:BreadcrumbBar", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Windows.Foundation.IInspectable"),
    ("_:BreadcrumbBar", "Loaded"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBar", "Loading"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Windows.Foundation.IInspectable"),
    ("_:BreadcrumbBar", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:BreadcrumbBar", "Unloaded"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBar", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:BreadcrumbBar", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:BreadcrumbBar", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:BreadcrumbBar", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:BreadcrumbBar", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:BreadcrumbBar", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBar", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:BreadcrumbBar", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:BreadcrumbBar", "DragEnter"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:BreadcrumbBar", "DragLeave"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:BreadcrumbBar", "DragOver"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:BreadcrumbBar", "DragStarting"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:BreadcrumbBar", "Drop"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:BreadcrumbBar", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:BreadcrumbBar", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:BreadcrumbBar", "GotFocus"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBar", "Holding"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:BreadcrumbBar", "KeyDown"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:BreadcrumbBar", "KeyUp"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:BreadcrumbBar", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:BreadcrumbBar", "LostFocus"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBar", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:BreadcrumbBar", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:BreadcrumbBar", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:BreadcrumbBar", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:BreadcrumbBar", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:BreadcrumbBar", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:BreadcrumbBar", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBar", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBar", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBar", "PointerExited"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBar", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBar", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBar", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBar", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBar", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:BreadcrumbBar", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:BreadcrumbBar", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBar", "RightTapped"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:BreadcrumbBar", "Tapped"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:BreadcrumbBar", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:BreadcrumbBar", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:BreadcrumbBar", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBar", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:BreadcrumbBarItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Windows.Foundation.IInspectable"),
    ("_:BreadcrumbBarItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:BreadcrumbBarItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:BreadcrumbBarItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Windows.Foundation.IInspectable"),
    ("_:BreadcrumbBarItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBarItem", "Loading"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Windows.Foundation.IInspectable"),
    ("_:BreadcrumbBarItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:BreadcrumbBarItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBarItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:BreadcrumbBarItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:BreadcrumbBarItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:BreadcrumbBarItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:BreadcrumbBarItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBarItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:BreadcrumbBarItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:BreadcrumbBarItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:BreadcrumbBarItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:BreadcrumbBarItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:BreadcrumbBarItem", "Drop"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:BreadcrumbBarItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:BreadcrumbBarItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:BreadcrumbBarItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBarItem", "Holding"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:BreadcrumbBarItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:BreadcrumbBarItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBarItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:BreadcrumbBarItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:BreadcrumbBarItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:BreadcrumbBarItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:BreadcrumbBarItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:BreadcrumbBarItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.BreadcrumbBarItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Button", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Button", "Windows.Foundation.IInspectable"),
    ("_:Button", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Button", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Button", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Button", "Windows.Foundation.IInspectable"),
    ("_:Button", "Loaded"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Button", "Loading"): ("Microsoft.UI.Xaml.Controls.Button", "Windows.Foundation.IInspectable"),
    ("_:Button", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Button", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Button", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Button", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Button", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Button", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Button", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Button", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Button", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Button", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Button", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Button", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Button", "DragOver"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Button", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Button", "Drop"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Button", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Button", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Button", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Button", "Holding"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Button", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Button", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Button", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Button", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Button", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Button", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Button", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Button", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Button", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Button", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Button", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Button", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Button", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Button", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Button", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Button", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Button", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Button", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Button", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Button", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Button", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Button", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Button", "Tapped"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Button", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:Button", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:Button", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Button", "Click"): ("Microsoft.UI.Xaml.Controls.Button", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarDatePicker", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Windows.Foundation.IInspectable"),
    ("_:CalendarDatePicker", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:CalendarDatePicker", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:CalendarDatePicker", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Windows.Foundation.IInspectable"),
    ("_:CalendarDatePicker", "Loaded"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarDatePicker", "Loading"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Windows.Foundation.IInspectable"),
    ("_:CalendarDatePicker", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:CalendarDatePicker", "Unloaded"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarDatePicker", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:CalendarDatePicker", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:CalendarDatePicker", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:CalendarDatePicker", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:CalendarDatePicker", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:CalendarDatePicker", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarDatePicker", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:CalendarDatePicker", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:CalendarDatePicker", "DragEnter"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CalendarDatePicker", "DragLeave"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CalendarDatePicker", "DragOver"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CalendarDatePicker", "DragStarting"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:CalendarDatePicker", "Drop"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CalendarDatePicker", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:CalendarDatePicker", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:CalendarDatePicker", "GotFocus"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarDatePicker", "Holding"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:CalendarDatePicker", "KeyDown"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CalendarDatePicker", "KeyUp"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CalendarDatePicker", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:CalendarDatePicker", "LostFocus"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarDatePicker", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:CalendarDatePicker", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:CalendarDatePicker", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:CalendarDatePicker", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:CalendarDatePicker", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:CalendarDatePicker", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:CalendarDatePicker", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarDatePicker", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarDatePicker", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarDatePicker", "PointerExited"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarDatePicker", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarDatePicker", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarDatePicker", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarDatePicker", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarDatePicker", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CalendarDatePicker", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CalendarDatePicker", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarDatePicker", "RightTapped"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:CalendarDatePicker", "Tapped"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:CalendarDatePicker", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:CalendarDatePicker", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:CalendarDatePicker", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.CalendarDatePicker", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:CalendarView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Windows.Foundation.IInspectable"),
    ("_:CalendarView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:CalendarView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:CalendarView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Windows.Foundation.IInspectable"),
    ("_:CalendarView", "Loaded"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarView", "Loading"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Windows.Foundation.IInspectable"),
    ("_:CalendarView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:CalendarView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:CalendarView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:CalendarView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:CalendarView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:CalendarView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:CalendarView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:CalendarView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:CalendarView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CalendarView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CalendarView", "DragOver"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CalendarView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:CalendarView", "Drop"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CalendarView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:CalendarView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:CalendarView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarView", "Holding"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:CalendarView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CalendarView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CalendarView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:CalendarView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:CalendarView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:CalendarView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:CalendarView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:CalendarView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:CalendarView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:CalendarView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CalendarView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CalendarView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CalendarView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CalendarView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:CalendarView", "Tapped"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:CalendarView", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:CalendarView", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:CalendarView", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.CalendarView", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:CheckBox", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Windows.Foundation.IInspectable"),
    ("_:CheckBox", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:CheckBox", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:CheckBox", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Windows.Foundation.IInspectable"),
    ("_:CheckBox", "Loaded"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CheckBox", "Loading"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Windows.Foundation.IInspectable"),
    ("_:CheckBox", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:CheckBox", "Unloaded"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CheckBox", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:CheckBox", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:CheckBox", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:CheckBox", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:CheckBox", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:CheckBox", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CheckBox", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:CheckBox", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:CheckBox", "DragEnter"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CheckBox", "DragLeave"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CheckBox", "DragOver"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CheckBox", "DragStarting"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:CheckBox", "Drop"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:CheckBox", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:CheckBox", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:CheckBox", "GotFocus"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CheckBox", "Holding"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:CheckBox", "KeyDown"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CheckBox", "KeyUp"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CheckBox", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:CheckBox", "LostFocus"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CheckBox", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:CheckBox", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:CheckBox", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:CheckBox", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:CheckBox", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:CheckBox", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:CheckBox", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CheckBox", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CheckBox", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CheckBox", "PointerExited"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CheckBox", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CheckBox", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CheckBox", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CheckBox", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:CheckBox", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CheckBox", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:CheckBox", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CheckBox", "RightTapped"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:CheckBox", "Tapped"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:CheckBox", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:CheckBox", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:CheckBox", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:CheckBox", "Click"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CheckBox", "Checked"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CheckBox", "Indeterminate"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:CheckBox", "Unchecked"): ("Microsoft.UI.Xaml.Controls.CheckBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ColorPicker", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Windows.Foundation.IInspectable"),
    ("_:ColorPicker", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ColorPicker", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ColorPicker", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Windows.Foundation.IInspectable"),
    ("_:ColorPicker", "Loaded"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ColorPicker", "Loading"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Windows.Foundation.IInspectable"),
    ("_:ColorPicker", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ColorPicker", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ColorPicker", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ColorPicker", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ColorPicker", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ColorPicker", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ColorPicker", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ColorPicker", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ColorPicker", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ColorPicker", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ColorPicker", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ColorPicker", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ColorPicker", "DragOver"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ColorPicker", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ColorPicker", "Drop"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ColorPicker", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ColorPicker", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ColorPicker", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ColorPicker", "Holding"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ColorPicker", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ColorPicker", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ColorPicker", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ColorPicker", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ColorPicker", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ColorPicker", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ColorPicker", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ColorPicker", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ColorPicker", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ColorPicker", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ColorPicker", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ColorPicker", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ColorPicker", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ColorPicker", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ColorPicker", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ColorPicker", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ColorPicker", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ColorPicker", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ColorPicker", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ColorPicker", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ColorPicker", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ColorPicker", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ColorPicker", "Tapped"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ColorPicker", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ColorPicker", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ColorPicker", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ColorPicker", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ComboBox", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Windows.Foundation.IInspectable"),
    ("_:ComboBox", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ComboBox", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ComboBox", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Windows.Foundation.IInspectable"),
    ("_:ComboBox", "Loaded"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBox", "Loading"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Windows.Foundation.IInspectable"),
    ("_:ComboBox", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ComboBox", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBox", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ComboBox", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ComboBox", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ComboBox", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ComboBox", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ComboBox", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBox", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ComboBox", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ComboBox", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ComboBox", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ComboBox", "DragOver"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ComboBox", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ComboBox", "Drop"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ComboBox", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ComboBox", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ComboBox", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBox", "Holding"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ComboBox", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ComboBox", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ComboBox", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ComboBox", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBox", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ComboBox", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ComboBox", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ComboBox", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ComboBox", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ComboBox", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ComboBox", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBox", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBox", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBox", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBox", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBox", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBox", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBox", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBox", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ComboBox", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ComboBox", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBox", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ComboBox", "Tapped"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ComboBox", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ComboBox", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ComboBox", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ComboBox", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.ComboBox", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:ComboBoxItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Windows.Foundation.IInspectable"),
    ("_:ComboBoxItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ComboBoxItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ComboBoxItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Windows.Foundation.IInspectable"),
    ("_:ComboBoxItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBoxItem", "Loading"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Windows.Foundation.IInspectable"),
    ("_:ComboBoxItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ComboBoxItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBoxItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ComboBoxItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ComboBoxItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ComboBoxItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ComboBoxItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ComboBoxItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBoxItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ComboBoxItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ComboBoxItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ComboBoxItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ComboBoxItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ComboBoxItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ComboBoxItem", "Drop"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ComboBoxItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ComboBoxItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ComboBoxItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBoxItem", "Holding"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ComboBoxItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ComboBoxItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ComboBoxItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ComboBoxItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBoxItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ComboBoxItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ComboBoxItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ComboBoxItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ComboBoxItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ComboBoxItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ComboBoxItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBoxItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBoxItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBoxItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBoxItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBoxItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBoxItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBoxItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ComboBoxItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ComboBoxItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ComboBoxItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ComboBoxItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ComboBoxItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ComboBoxItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ComboBoxItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ComboBoxItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ComboBoxItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:CommandBarFlyout", "Closed"): ("Microsoft.UI.Xaml.Controls.CommandBarFlyout", "Windows.Foundation.IInspectable"),
    ("_:CommandBarFlyout", "Closing"): ("Microsoft.UI.Xaml.Controls.CommandBarFlyout", "Microsoft.UI.Xaml.Controls.FlyoutBaseClosingEventArgs"),
    ("_:CommandBarFlyout", "Opened"): ("Microsoft.UI.Xaml.Controls.CommandBarFlyout", "Windows.Foundation.IInspectable"),
    ("_:CommandBarFlyout", "Opening"): ("Microsoft.UI.Xaml.Controls.CommandBarFlyout", "Windows.Foundation.IInspectable"),
    ("_:ContentControl", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Windows.Foundation.IInspectable"),
    ("_:ContentControl", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ContentControl", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ContentControl", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Windows.Foundation.IInspectable"),
    ("_:ContentControl", "Loaded"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentControl", "Loading"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Windows.Foundation.IInspectable"),
    ("_:ContentControl", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ContentControl", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentControl", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ContentControl", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ContentControl", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ContentControl", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ContentControl", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ContentControl", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentControl", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ContentControl", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ContentControl", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentControl", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentControl", "DragOver"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentControl", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ContentControl", "Drop"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentControl", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ContentControl", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ContentControl", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentControl", "Holding"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ContentControl", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentControl", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentControl", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ContentControl", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentControl", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ContentControl", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ContentControl", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ContentControl", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ContentControl", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ContentControl", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ContentControl", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentControl", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentControl", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentControl", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentControl", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentControl", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentControl", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentControl", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentControl", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentControl", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentControl", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentControl", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ContentControl", "Tapped"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ContentControl", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ContentControl", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ContentControl", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ContentControl", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ContentDialog", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Windows.Foundation.IInspectable"),
    ("_:ContentDialog", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ContentDialog", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ContentDialog", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Windows.Foundation.IInspectable"),
    ("_:ContentDialog", "Loaded"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentDialog", "Loading"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Windows.Foundation.IInspectable"),
    ("_:ContentDialog", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ContentDialog", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentDialog", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ContentDialog", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ContentDialog", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ContentDialog", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ContentDialog", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ContentDialog", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentDialog", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ContentDialog", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ContentDialog", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentDialog", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentDialog", "DragOver"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentDialog", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ContentDialog", "Drop"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentDialog", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ContentDialog", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ContentDialog", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentDialog", "Holding"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ContentDialog", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentDialog", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentDialog", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ContentDialog", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentDialog", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ContentDialog", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ContentDialog", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ContentDialog", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ContentDialog", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ContentDialog", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ContentDialog", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentDialog", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentDialog", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentDialog", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentDialog", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentDialog", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentDialog", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentDialog", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentDialog", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentDialog", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentDialog", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentDialog", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ContentDialog", "Tapped"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ContentDialog", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ContentDialog", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ContentDialog", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ContentDialog", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ContentPresenter", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Windows.Foundation.IInspectable"),
    ("_:ContentPresenter", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ContentPresenter", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ContentPresenter", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Windows.Foundation.IInspectable"),
    ("_:ContentPresenter", "Loaded"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentPresenter", "Loading"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Windows.Foundation.IInspectable"),
    ("_:ContentPresenter", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ContentPresenter", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentPresenter", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ContentPresenter", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ContentPresenter", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ContentPresenter", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ContentPresenter", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ContentPresenter", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentPresenter", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ContentPresenter", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ContentPresenter", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentPresenter", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentPresenter", "DragOver"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentPresenter", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ContentPresenter", "Drop"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ContentPresenter", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ContentPresenter", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ContentPresenter", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentPresenter", "Holding"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ContentPresenter", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentPresenter", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentPresenter", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ContentPresenter", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentPresenter", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ContentPresenter", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ContentPresenter", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ContentPresenter", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ContentPresenter", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ContentPresenter", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ContentPresenter", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentPresenter", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentPresenter", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentPresenter", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentPresenter", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentPresenter", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentPresenter", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentPresenter", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ContentPresenter", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentPresenter", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ContentPresenter", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ContentPresenter", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ContentPresenter", "Tapped"): ("Microsoft.UI.Xaml.Controls.ContentPresenter", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Control", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:Control", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:Control", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Control", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Control", "Windows.Foundation.IInspectable"),
    ("_:Control", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Control", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Control", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Control", "Windows.Foundation.IInspectable"),
    ("_:Control", "Loaded"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Control", "Loading"): ("Microsoft.UI.Xaml.Controls.Control", "Windows.Foundation.IInspectable"),
    ("_:Control", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Control", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Control", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Control", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Control", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Control", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Control", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Control", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Control", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Control", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Control", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Control", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Control", "DragOver"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Control", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Control", "Drop"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Control", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Control", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Control", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Control", "Holding"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Control", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Control", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Control", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Control", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Control", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Control", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Control", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Control", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Control", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Control", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Control", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Control", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Control", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Control", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Control", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Control", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Control", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Control", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Control", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Control", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Control", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Control", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Control", "Tapped"): ("Microsoft.UI.Xaml.Controls.Control", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:DatePicker", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Windows.Foundation.IInspectable"),
    ("_:DatePicker", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:DatePicker", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:DatePicker", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Windows.Foundation.IInspectable"),
    ("_:DatePicker", "Loaded"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DatePicker", "Loading"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Windows.Foundation.IInspectable"),
    ("_:DatePicker", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:DatePicker", "Unloaded"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DatePicker", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:DatePicker", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:DatePicker", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:DatePicker", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:DatePicker", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:DatePicker", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DatePicker", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:DatePicker", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:DatePicker", "DragEnter"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:DatePicker", "DragLeave"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:DatePicker", "DragOver"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:DatePicker", "DragStarting"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:DatePicker", "Drop"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:DatePicker", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:DatePicker", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:DatePicker", "GotFocus"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DatePicker", "Holding"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:DatePicker", "KeyDown"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:DatePicker", "KeyUp"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:DatePicker", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:DatePicker", "LostFocus"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DatePicker", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:DatePicker", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:DatePicker", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:DatePicker", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:DatePicker", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:DatePicker", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:DatePicker", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DatePicker", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DatePicker", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DatePicker", "PointerExited"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DatePicker", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DatePicker", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DatePicker", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DatePicker", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DatePicker", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:DatePicker", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:DatePicker", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DatePicker", "RightTapped"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:DatePicker", "Tapped"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:DatePicker", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:DatePicker", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:DatePicker", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.DatePicker", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:DropDownButton", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Windows.Foundation.IInspectable"),
    ("_:DropDownButton", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:DropDownButton", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:DropDownButton", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Windows.Foundation.IInspectable"),
    ("_:DropDownButton", "Loaded"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DropDownButton", "Loading"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Windows.Foundation.IInspectable"),
    ("_:DropDownButton", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:DropDownButton", "Unloaded"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DropDownButton", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:DropDownButton", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:DropDownButton", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:DropDownButton", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:DropDownButton", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:DropDownButton", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DropDownButton", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:DropDownButton", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:DropDownButton", "DragEnter"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:DropDownButton", "DragLeave"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:DropDownButton", "DragOver"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:DropDownButton", "DragStarting"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:DropDownButton", "Drop"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:DropDownButton", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:DropDownButton", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:DropDownButton", "GotFocus"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DropDownButton", "Holding"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:DropDownButton", "KeyDown"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:DropDownButton", "KeyUp"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:DropDownButton", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:DropDownButton", "LostFocus"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DropDownButton", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:DropDownButton", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:DropDownButton", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:DropDownButton", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:DropDownButton", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:DropDownButton", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:DropDownButton", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DropDownButton", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DropDownButton", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DropDownButton", "PointerExited"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DropDownButton", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DropDownButton", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DropDownButton", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DropDownButton", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:DropDownButton", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:DropDownButton", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:DropDownButton", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:DropDownButton", "RightTapped"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:DropDownButton", "Tapped"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:DropDownButton", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:DropDownButton", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:DropDownButton", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:DropDownButton", "Click"): ("Microsoft.UI.Xaml.Controls.DropDownButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Expander", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Expander", "Windows.Foundation.IInspectable"),
    ("_:Expander", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Expander", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Expander", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Expander", "Windows.Foundation.IInspectable"),
    ("_:Expander", "Loaded"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Expander", "Loading"): ("Microsoft.UI.Xaml.Controls.Expander", "Windows.Foundation.IInspectable"),
    ("_:Expander", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Expander", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Expander", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Expander", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Expander", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Expander", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Expander", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Expander", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Expander", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Expander", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Expander", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Expander", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Expander", "DragOver"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Expander", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Expander", "Drop"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Expander", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Expander", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Expander", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Expander", "Holding"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Expander", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Expander", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Expander", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Expander", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Expander", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Expander", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Expander", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Expander", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Expander", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Expander", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Expander", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Expander", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Expander", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Expander", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Expander", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Expander", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Expander", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Expander", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Expander", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Expander", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Expander", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Expander", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Expander", "Tapped"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Expander", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:Expander", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:Expander", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Expander", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:FlipView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.FlipView", "Windows.Foundation.IInspectable"),
    ("_:FlipView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:FlipView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:FlipView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.FlipView", "Windows.Foundation.IInspectable"),
    ("_:FlipView", "Loaded"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipView", "Loading"): ("Microsoft.UI.Xaml.Controls.FlipView", "Windows.Foundation.IInspectable"),
    ("_:FlipView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:FlipView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:FlipView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:FlipView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:FlipView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:FlipView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:FlipView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:FlipView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:FlipView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlipView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlipView", "DragOver"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlipView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:FlipView", "Drop"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlipView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:FlipView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:FlipView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipView", "Holding"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:FlipView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlipView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlipView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:FlipView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:FlipView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:FlipView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:FlipView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:FlipView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:FlipView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:FlipView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlipView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlipView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:FlipView", "Tapped"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:FlipView", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:FlipView", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:FlipView", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:FlipView", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.FlipView", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:FlipViewItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Windows.Foundation.IInspectable"),
    ("_:FlipViewItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:FlipViewItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:FlipViewItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Windows.Foundation.IInspectable"),
    ("_:FlipViewItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipViewItem", "Loading"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Windows.Foundation.IInspectable"),
    ("_:FlipViewItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:FlipViewItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipViewItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:FlipViewItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:FlipViewItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:FlipViewItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:FlipViewItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:FlipViewItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipViewItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:FlipViewItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:FlipViewItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlipViewItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlipViewItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlipViewItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:FlipViewItem", "Drop"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlipViewItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:FlipViewItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:FlipViewItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipViewItem", "Holding"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:FlipViewItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlipViewItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlipViewItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:FlipViewItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipViewItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:FlipViewItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:FlipViewItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:FlipViewItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:FlipViewItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:FlipViewItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:FlipViewItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipViewItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipViewItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipViewItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipViewItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipViewItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipViewItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipViewItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlipViewItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlipViewItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlipViewItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlipViewItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:FlipViewItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:FlipViewItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:FlipViewItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:FlipViewItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.FlipViewItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Flyout", "Closed"): ("Microsoft.UI.Xaml.Controls.Flyout", "Windows.Foundation.IInspectable"),
    ("_:Flyout", "Closing"): ("Microsoft.UI.Xaml.Controls.Flyout", "Microsoft.UI.Xaml.Controls.FlyoutBaseClosingEventArgs"),
    ("_:Flyout", "Opened"): ("Microsoft.UI.Xaml.Controls.Flyout", "Windows.Foundation.IInspectable"),
    ("_:Flyout", "Opening"): ("Microsoft.UI.Xaml.Controls.Flyout", "Windows.Foundation.IInspectable"),
    ("_:FlyoutPresenter", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Windows.Foundation.IInspectable"),
    ("_:FlyoutPresenter", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:FlyoutPresenter", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:FlyoutPresenter", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Windows.Foundation.IInspectable"),
    ("_:FlyoutPresenter", "Loaded"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlyoutPresenter", "Loading"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Windows.Foundation.IInspectable"),
    ("_:FlyoutPresenter", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:FlyoutPresenter", "Unloaded"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlyoutPresenter", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:FlyoutPresenter", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:FlyoutPresenter", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:FlyoutPresenter", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:FlyoutPresenter", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:FlyoutPresenter", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlyoutPresenter", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:FlyoutPresenter", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:FlyoutPresenter", "DragEnter"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlyoutPresenter", "DragLeave"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlyoutPresenter", "DragOver"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlyoutPresenter", "DragStarting"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:FlyoutPresenter", "Drop"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FlyoutPresenter", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:FlyoutPresenter", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:FlyoutPresenter", "GotFocus"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlyoutPresenter", "Holding"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:FlyoutPresenter", "KeyDown"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlyoutPresenter", "KeyUp"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlyoutPresenter", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:FlyoutPresenter", "LostFocus"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlyoutPresenter", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:FlyoutPresenter", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:FlyoutPresenter", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:FlyoutPresenter", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:FlyoutPresenter", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:FlyoutPresenter", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:FlyoutPresenter", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlyoutPresenter", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlyoutPresenter", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlyoutPresenter", "PointerExited"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlyoutPresenter", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlyoutPresenter", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlyoutPresenter", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlyoutPresenter", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FlyoutPresenter", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlyoutPresenter", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FlyoutPresenter", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FlyoutPresenter", "RightTapped"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:FlyoutPresenter", "Tapped"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:FlyoutPresenter", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:FlyoutPresenter", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:FlyoutPresenter", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.FlyoutPresenter", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:FontIcon", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Windows.Foundation.IInspectable"),
    ("_:FontIcon", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:FontIcon", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:FontIcon", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Windows.Foundation.IInspectable"),
    ("_:FontIcon", "Loaded"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FontIcon", "Loading"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Windows.Foundation.IInspectable"),
    ("_:FontIcon", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:FontIcon", "Unloaded"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FontIcon", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:FontIcon", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:FontIcon", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:FontIcon", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:FontIcon", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:FontIcon", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FontIcon", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:FontIcon", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:FontIcon", "DragEnter"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FontIcon", "DragLeave"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FontIcon", "DragOver"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FontIcon", "DragStarting"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:FontIcon", "Drop"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:FontIcon", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:FontIcon", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:FontIcon", "GotFocus"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FontIcon", "Holding"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:FontIcon", "KeyDown"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FontIcon", "KeyUp"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FontIcon", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:FontIcon", "LostFocus"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FontIcon", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:FontIcon", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:FontIcon", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:FontIcon", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:FontIcon", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:FontIcon", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:FontIcon", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FontIcon", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FontIcon", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FontIcon", "PointerExited"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FontIcon", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FontIcon", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FontIcon", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FontIcon", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:FontIcon", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FontIcon", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:FontIcon", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:FontIcon", "RightTapped"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:FontIcon", "Tapped"): ("Microsoft.UI.Xaml.Controls.FontIcon", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Frame", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Frame", "Windows.Foundation.IInspectable"),
    ("_:Frame", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Frame", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Frame", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Frame", "Windows.Foundation.IInspectable"),
    ("_:Frame", "Loaded"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Frame", "Loading"): ("Microsoft.UI.Xaml.Controls.Frame", "Windows.Foundation.IInspectable"),
    ("_:Frame", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Frame", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Frame", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Frame", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Frame", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Frame", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Frame", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Frame", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Frame", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Frame", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Frame", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Frame", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Frame", "DragOver"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Frame", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Frame", "Drop"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Frame", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Frame", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Frame", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Frame", "Holding"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Frame", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Frame", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Frame", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Frame", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Frame", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Frame", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Frame", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Frame", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Frame", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Frame", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Frame", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Frame", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Frame", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Frame", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Frame", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Frame", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Frame", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Frame", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Frame", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Frame", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Frame", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Frame", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Frame", "Tapped"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Frame", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:Frame", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:Frame", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Frame", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Grid", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Grid", "Windows.Foundation.IInspectable"),
    ("_:Grid", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Grid", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Grid", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Grid", "Windows.Foundation.IInspectable"),
    ("_:Grid", "Loaded"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Grid", "Loading"): ("Microsoft.UI.Xaml.Controls.Grid", "Windows.Foundation.IInspectable"),
    ("_:Grid", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Grid", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Grid", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Grid", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Grid", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Grid", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Grid", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Grid", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Grid", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Grid", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Grid", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Grid", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Grid", "DragOver"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Grid", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Grid", "Drop"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Grid", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Grid", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Grid", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Grid", "Holding"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Grid", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Grid", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Grid", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Grid", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Grid", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Grid", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Grid", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Grid", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Grid", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Grid", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Grid", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Grid", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Grid", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Grid", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Grid", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Grid", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Grid", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Grid", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Grid", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Grid", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Grid", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Grid", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Grid", "Tapped"): ("Microsoft.UI.Xaml.Controls.Grid", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:GridView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.GridView", "Windows.Foundation.IInspectable"),
    ("_:GridView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:GridView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:GridView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.GridView", "Windows.Foundation.IInspectable"),
    ("_:GridView", "Loaded"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridView", "Loading"): ("Microsoft.UI.Xaml.Controls.GridView", "Windows.Foundation.IInspectable"),
    ("_:GridView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:GridView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:GridView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:GridView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:GridView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:GridView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:GridView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:GridView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:GridView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridView", "DragOver"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:GridView", "Drop"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:GridView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:GridView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridView", "Holding"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:GridView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:GridView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:GridView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:GridView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:GridView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:GridView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:GridView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:GridView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:GridView", "Tapped"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:GridView", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:GridView", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:GridView", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:GridView", "DragItemsCompleted"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.DragItemsCompletedEventArgs"),
    ("_:GridView", "DragItemsStarting"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.DragItemsStartingEventArgs"),
    ("_:GridView", "ItemClick"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.ItemClickEventArgs"),
    ("_:GridView", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.GridView", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:GridViewHeaderItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Windows.Foundation.IInspectable"),
    ("_:GridViewHeaderItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:GridViewHeaderItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:GridViewHeaderItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Windows.Foundation.IInspectable"),
    ("_:GridViewHeaderItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewHeaderItem", "Loading"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Windows.Foundation.IInspectable"),
    ("_:GridViewHeaderItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:GridViewHeaderItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewHeaderItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:GridViewHeaderItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:GridViewHeaderItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:GridViewHeaderItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:GridViewHeaderItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:GridViewHeaderItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewHeaderItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:GridViewHeaderItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:GridViewHeaderItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridViewHeaderItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridViewHeaderItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridViewHeaderItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:GridViewHeaderItem", "Drop"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridViewHeaderItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:GridViewHeaderItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:GridViewHeaderItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewHeaderItem", "Holding"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:GridViewHeaderItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridViewHeaderItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridViewHeaderItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:GridViewHeaderItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewHeaderItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:GridViewHeaderItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:GridViewHeaderItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:GridViewHeaderItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:GridViewHeaderItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:GridViewHeaderItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:GridViewHeaderItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewHeaderItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewHeaderItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewHeaderItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewHeaderItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewHeaderItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewHeaderItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewHeaderItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewHeaderItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridViewHeaderItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridViewHeaderItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewHeaderItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:GridViewHeaderItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:GridViewHeaderItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:GridViewHeaderItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:GridViewHeaderItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.GridViewHeaderItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:GridViewItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Windows.Foundation.IInspectable"),
    ("_:GridViewItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:GridViewItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:GridViewItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Windows.Foundation.IInspectable"),
    ("_:GridViewItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewItem", "Loading"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Windows.Foundation.IInspectable"),
    ("_:GridViewItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:GridViewItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:GridViewItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:GridViewItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:GridViewItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:GridViewItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:GridViewItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:GridViewItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:GridViewItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridViewItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridViewItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridViewItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:GridViewItem", "Drop"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GridViewItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:GridViewItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:GridViewItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewItem", "Holding"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:GridViewItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridViewItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridViewItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:GridViewItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:GridViewItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:GridViewItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:GridViewItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:GridViewItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:GridViewItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:GridViewItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GridViewItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridViewItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GridViewItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GridViewItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:GridViewItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:GridViewItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:GridViewItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:GridViewItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.GridViewItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:GroupItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Windows.Foundation.IInspectable"),
    ("_:GroupItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:GroupItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:GroupItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Windows.Foundation.IInspectable"),
    ("_:GroupItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GroupItem", "Loading"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Windows.Foundation.IInspectable"),
    ("_:GroupItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:GroupItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GroupItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:GroupItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:GroupItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:GroupItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:GroupItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:GroupItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GroupItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:GroupItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:GroupItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GroupItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GroupItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GroupItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:GroupItem", "Drop"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:GroupItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:GroupItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:GroupItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GroupItem", "Holding"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:GroupItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GroupItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GroupItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:GroupItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GroupItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:GroupItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:GroupItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:GroupItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:GroupItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:GroupItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:GroupItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GroupItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GroupItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GroupItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GroupItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GroupItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GroupItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GroupItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:GroupItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GroupItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:GroupItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:GroupItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:GroupItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:GroupItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:GroupItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:GroupItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.GroupItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Hub", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Hub", "Windows.Foundation.IInspectable"),
    ("_:Hub", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Hub", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Hub", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Hub", "Windows.Foundation.IInspectable"),
    ("_:Hub", "Loaded"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Hub", "Loading"): ("Microsoft.UI.Xaml.Controls.Hub", "Windows.Foundation.IInspectable"),
    ("_:Hub", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Hub", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Hub", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Hub", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Hub", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Hub", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Hub", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Hub", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Hub", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Hub", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Hub", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Hub", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Hub", "DragOver"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Hub", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Hub", "Drop"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Hub", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Hub", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Hub", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Hub", "Holding"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Hub", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Hub", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Hub", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Hub", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Hub", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Hub", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Hub", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Hub", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Hub", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Hub", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Hub", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Hub", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Hub", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Hub", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Hub", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Hub", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Hub", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Hub", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Hub", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Hub", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Hub", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Hub", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Hub", "Tapped"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Hub", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:Hub", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:Hub", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Hub", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:HubSection", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.HubSection", "Windows.Foundation.IInspectable"),
    ("_:HubSection", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:HubSection", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:HubSection", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.HubSection", "Windows.Foundation.IInspectable"),
    ("_:HubSection", "Loaded"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HubSection", "Loading"): ("Microsoft.UI.Xaml.Controls.HubSection", "Windows.Foundation.IInspectable"),
    ("_:HubSection", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:HubSection", "Unloaded"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HubSection", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:HubSection", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:HubSection", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:HubSection", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:HubSection", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:HubSection", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HubSection", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:HubSection", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:HubSection", "DragEnter"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:HubSection", "DragLeave"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:HubSection", "DragOver"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:HubSection", "DragStarting"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:HubSection", "Drop"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:HubSection", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:HubSection", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:HubSection", "GotFocus"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HubSection", "Holding"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:HubSection", "KeyDown"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:HubSection", "KeyUp"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:HubSection", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:HubSection", "LostFocus"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HubSection", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:HubSection", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:HubSection", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:HubSection", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:HubSection", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:HubSection", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:HubSection", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HubSection", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HubSection", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HubSection", "PointerExited"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HubSection", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HubSection", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HubSection", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HubSection", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HubSection", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:HubSection", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:HubSection", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HubSection", "RightTapped"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:HubSection", "Tapped"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:HubSection", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:HubSection", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:HubSection", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.HubSection", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:HyperlinkButton", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Windows.Foundation.IInspectable"),
    ("_:HyperlinkButton", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:HyperlinkButton", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:HyperlinkButton", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Windows.Foundation.IInspectable"),
    ("_:HyperlinkButton", "Loaded"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HyperlinkButton", "Loading"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Windows.Foundation.IInspectable"),
    ("_:HyperlinkButton", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:HyperlinkButton", "Unloaded"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HyperlinkButton", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:HyperlinkButton", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:HyperlinkButton", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:HyperlinkButton", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:HyperlinkButton", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:HyperlinkButton", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HyperlinkButton", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:HyperlinkButton", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:HyperlinkButton", "DragEnter"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:HyperlinkButton", "DragLeave"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:HyperlinkButton", "DragOver"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:HyperlinkButton", "DragStarting"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:HyperlinkButton", "Drop"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:HyperlinkButton", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:HyperlinkButton", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:HyperlinkButton", "GotFocus"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HyperlinkButton", "Holding"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:HyperlinkButton", "KeyDown"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:HyperlinkButton", "KeyUp"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:HyperlinkButton", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:HyperlinkButton", "LostFocus"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HyperlinkButton", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:HyperlinkButton", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:HyperlinkButton", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:HyperlinkButton", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:HyperlinkButton", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:HyperlinkButton", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:HyperlinkButton", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HyperlinkButton", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HyperlinkButton", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HyperlinkButton", "PointerExited"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HyperlinkButton", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HyperlinkButton", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HyperlinkButton", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HyperlinkButton", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:HyperlinkButton", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:HyperlinkButton", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:HyperlinkButton", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:HyperlinkButton", "RightTapped"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:HyperlinkButton", "Tapped"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:HyperlinkButton", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:HyperlinkButton", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:HyperlinkButton", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:HyperlinkButton", "Click"): ("Microsoft.UI.Xaml.Controls.HyperlinkButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconElement", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.IconElement", "Windows.Foundation.IInspectable"),
    ("_:IconElement", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:IconElement", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:IconElement", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.IconElement", "Windows.Foundation.IInspectable"),
    ("_:IconElement", "Loaded"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconElement", "Loading"): ("Microsoft.UI.Xaml.Controls.IconElement", "Windows.Foundation.IInspectable"),
    ("_:IconElement", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:IconElement", "Unloaded"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconElement", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:IconElement", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:IconElement", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:IconElement", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:IconElement", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:IconElement", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconElement", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:IconElement", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:IconElement", "DragEnter"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:IconElement", "DragLeave"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:IconElement", "DragOver"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:IconElement", "DragStarting"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:IconElement", "Drop"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:IconElement", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:IconElement", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:IconElement", "GotFocus"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconElement", "Holding"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:IconElement", "KeyDown"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:IconElement", "KeyUp"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:IconElement", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:IconElement", "LostFocus"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconElement", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:IconElement", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:IconElement", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:IconElement", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:IconElement", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:IconElement", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:IconElement", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconElement", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconElement", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconElement", "PointerExited"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconElement", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconElement", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconElement", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconElement", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconElement", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:IconElement", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:IconElement", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconElement", "RightTapped"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:IconElement", "Tapped"): ("Microsoft.UI.Xaml.Controls.IconElement", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:IconSourceElement", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Windows.Foundation.IInspectable"),
    ("_:IconSourceElement", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:IconSourceElement", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:IconSourceElement", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Windows.Foundation.IInspectable"),
    ("_:IconSourceElement", "Loaded"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconSourceElement", "Loading"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Windows.Foundation.IInspectable"),
    ("_:IconSourceElement", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:IconSourceElement", "Unloaded"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconSourceElement", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:IconSourceElement", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:IconSourceElement", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:IconSourceElement", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:IconSourceElement", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:IconSourceElement", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconSourceElement", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:IconSourceElement", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:IconSourceElement", "DragEnter"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:IconSourceElement", "DragLeave"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:IconSourceElement", "DragOver"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:IconSourceElement", "DragStarting"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:IconSourceElement", "Drop"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:IconSourceElement", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:IconSourceElement", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:IconSourceElement", "GotFocus"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconSourceElement", "Holding"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:IconSourceElement", "KeyDown"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:IconSourceElement", "KeyUp"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:IconSourceElement", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:IconSourceElement", "LostFocus"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconSourceElement", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:IconSourceElement", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:IconSourceElement", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:IconSourceElement", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:IconSourceElement", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:IconSourceElement", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:IconSourceElement", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconSourceElement", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconSourceElement", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconSourceElement", "PointerExited"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconSourceElement", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconSourceElement", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconSourceElement", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconSourceElement", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:IconSourceElement", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:IconSourceElement", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:IconSourceElement", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:IconSourceElement", "RightTapped"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:IconSourceElement", "Tapped"): ("Microsoft.UI.Xaml.Controls.IconSourceElement", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Image", "ImageFailed"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.ExceptionRoutedEventArgs"),
    ("_:Image", "ImageOpened"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Image", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Image", "Windows.Foundation.IInspectable"),
    ("_:Image", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Image", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Image", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Image", "Windows.Foundation.IInspectable"),
    ("_:Image", "Loaded"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Image", "Loading"): ("Microsoft.UI.Xaml.Controls.Image", "Windows.Foundation.IInspectable"),
    ("_:Image", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Image", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Image", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Image", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Image", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Image", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Image", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Image", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Image", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Image", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Image", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Image", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Image", "DragOver"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Image", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Image", "Drop"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Image", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Image", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Image", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Image", "Holding"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Image", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Image", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Image", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Image", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Image", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Image", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Image", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Image", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Image", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Image", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Image", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Image", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Image", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Image", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Image", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Image", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Image", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Image", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Image", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Image", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Image", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Image", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Image", "Tapped"): ("Microsoft.UI.Xaml.Controls.Image", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ImageIcon", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Windows.Foundation.IInspectable"),
    ("_:ImageIcon", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ImageIcon", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ImageIcon", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Windows.Foundation.IInspectable"),
    ("_:ImageIcon", "Loaded"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ImageIcon", "Loading"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Windows.Foundation.IInspectable"),
    ("_:ImageIcon", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ImageIcon", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ImageIcon", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ImageIcon", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ImageIcon", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ImageIcon", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ImageIcon", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ImageIcon", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ImageIcon", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ImageIcon", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ImageIcon", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ImageIcon", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ImageIcon", "DragOver"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ImageIcon", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ImageIcon", "Drop"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ImageIcon", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ImageIcon", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ImageIcon", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ImageIcon", "Holding"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ImageIcon", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ImageIcon", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ImageIcon", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ImageIcon", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ImageIcon", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ImageIcon", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ImageIcon", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ImageIcon", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ImageIcon", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ImageIcon", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ImageIcon", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ImageIcon", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ImageIcon", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ImageIcon", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ImageIcon", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ImageIcon", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ImageIcon", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ImageIcon", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ImageIcon", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ImageIcon", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ImageIcon", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ImageIcon", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ImageIcon", "Tapped"): ("Microsoft.UI.Xaml.Controls.ImageIcon", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:InfoBadge", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Windows.Foundation.IInspectable"),
    ("_:InfoBadge", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:InfoBadge", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:InfoBadge", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Windows.Foundation.IInspectable"),
    ("_:InfoBadge", "Loaded"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBadge", "Loading"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Windows.Foundation.IInspectable"),
    ("_:InfoBadge", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:InfoBadge", "Unloaded"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBadge", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:InfoBadge", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:InfoBadge", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:InfoBadge", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:InfoBadge", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:InfoBadge", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBadge", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:InfoBadge", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:InfoBadge", "DragEnter"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:InfoBadge", "DragLeave"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:InfoBadge", "DragOver"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:InfoBadge", "DragStarting"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:InfoBadge", "Drop"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:InfoBadge", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:InfoBadge", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:InfoBadge", "GotFocus"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBadge", "Holding"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:InfoBadge", "KeyDown"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:InfoBadge", "KeyUp"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:InfoBadge", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:InfoBadge", "LostFocus"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBadge", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:InfoBadge", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:InfoBadge", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:InfoBadge", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:InfoBadge", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:InfoBadge", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:InfoBadge", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBadge", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBadge", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBadge", "PointerExited"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBadge", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBadge", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBadge", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBadge", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBadge", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:InfoBadge", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:InfoBadge", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBadge", "RightTapped"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:InfoBadge", "Tapped"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:InfoBadge", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:InfoBadge", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:InfoBadge", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.InfoBadge", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:InfoBar", "CloseButtonClick"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Windows.Foundation.IInspectable"),
    ("_:InfoBar", "Closed"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.InfoBarClosedEventArgs"),
    ("_:InfoBar", "Closing"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.InfoBarClosingEventArgs"),
    ("_:InfoBar", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Windows.Foundation.IInspectable"),
    ("_:InfoBar", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:InfoBar", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:InfoBar", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Windows.Foundation.IInspectable"),
    ("_:InfoBar", "Loaded"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBar", "Loading"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Windows.Foundation.IInspectable"),
    ("_:InfoBar", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:InfoBar", "Unloaded"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBar", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:InfoBar", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:InfoBar", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:InfoBar", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:InfoBar", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:InfoBar", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBar", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:InfoBar", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:InfoBar", "DragEnter"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:InfoBar", "DragLeave"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:InfoBar", "DragOver"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:InfoBar", "DragStarting"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:InfoBar", "Drop"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:InfoBar", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:InfoBar", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:InfoBar", "GotFocus"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBar", "Holding"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:InfoBar", "KeyDown"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:InfoBar", "KeyUp"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:InfoBar", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:InfoBar", "LostFocus"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBar", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:InfoBar", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:InfoBar", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:InfoBar", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:InfoBar", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:InfoBar", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:InfoBar", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBar", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBar", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBar", "PointerExited"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBar", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBar", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBar", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBar", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:InfoBar", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:InfoBar", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:InfoBar", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:InfoBar", "RightTapped"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:InfoBar", "Tapped"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:InfoBar", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:InfoBar", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:InfoBar", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.InfoBar", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ItemContainer", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Windows.Foundation.IInspectable"),
    ("_:ItemContainer", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ItemContainer", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ItemContainer", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Windows.Foundation.IInspectable"),
    ("_:ItemContainer", "Loaded"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemContainer", "Loading"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Windows.Foundation.IInspectable"),
    ("_:ItemContainer", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ItemContainer", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemContainer", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ItemContainer", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ItemContainer", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ItemContainer", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ItemContainer", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ItemContainer", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemContainer", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ItemContainer", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ItemContainer", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemContainer", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemContainer", "DragOver"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemContainer", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ItemContainer", "Drop"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemContainer", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ItemContainer", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ItemContainer", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemContainer", "Holding"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ItemContainer", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemContainer", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemContainer", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ItemContainer", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemContainer", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ItemContainer", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ItemContainer", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ItemContainer", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ItemContainer", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ItemContainer", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ItemContainer", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemContainer", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemContainer", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemContainer", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemContainer", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemContainer", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemContainer", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemContainer", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemContainer", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemContainer", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemContainer", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemContainer", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ItemContainer", "Tapped"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ItemContainer", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ItemContainer", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ItemContainer", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ItemContainer", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ItemsControl", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Windows.Foundation.IInspectable"),
    ("_:ItemsControl", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ItemsControl", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ItemsControl", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Windows.Foundation.IInspectable"),
    ("_:ItemsControl", "Loaded"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsControl", "Loading"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Windows.Foundation.IInspectable"),
    ("_:ItemsControl", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ItemsControl", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsControl", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ItemsControl", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ItemsControl", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ItemsControl", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ItemsControl", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ItemsControl", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsControl", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ItemsControl", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ItemsControl", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsControl", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsControl", "DragOver"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsControl", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ItemsControl", "Drop"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsControl", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ItemsControl", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ItemsControl", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsControl", "Holding"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ItemsControl", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsControl", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsControl", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ItemsControl", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsControl", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ItemsControl", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ItemsControl", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ItemsControl", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ItemsControl", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ItemsControl", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ItemsControl", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsControl", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsControl", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsControl", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsControl", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsControl", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsControl", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsControl", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsControl", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsControl", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsControl", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsControl", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ItemsControl", "Tapped"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ItemsControl", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ItemsControl", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ItemsControl", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ItemsControl", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ItemsStackPanel", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Windows.Foundation.IInspectable"),
    ("_:ItemsStackPanel", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ItemsStackPanel", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ItemsStackPanel", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Windows.Foundation.IInspectable"),
    ("_:ItemsStackPanel", "Loaded"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsStackPanel", "Loading"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Windows.Foundation.IInspectable"),
    ("_:ItemsStackPanel", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ItemsStackPanel", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsStackPanel", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ItemsStackPanel", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ItemsStackPanel", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ItemsStackPanel", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ItemsStackPanel", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ItemsStackPanel", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsStackPanel", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ItemsStackPanel", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ItemsStackPanel", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsStackPanel", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsStackPanel", "DragOver"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsStackPanel", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ItemsStackPanel", "Drop"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsStackPanel", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ItemsStackPanel", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ItemsStackPanel", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsStackPanel", "Holding"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ItemsStackPanel", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsStackPanel", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsStackPanel", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ItemsStackPanel", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsStackPanel", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ItemsStackPanel", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ItemsStackPanel", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ItemsStackPanel", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ItemsStackPanel", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ItemsStackPanel", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ItemsStackPanel", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsStackPanel", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsStackPanel", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsStackPanel", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsStackPanel", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsStackPanel", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsStackPanel", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsStackPanel", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsStackPanel", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsStackPanel", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsStackPanel", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsStackPanel", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ItemsStackPanel", "Tapped"): ("Microsoft.UI.Xaml.Controls.ItemsStackPanel", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ItemsView", "ItemInvoked"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.ItemsViewItemInvokedEventArgs"),
    ("_:ItemsView", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.ItemsViewSelectionChangedEventArgs"),
    ("_:ItemsView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Windows.Foundation.IInspectable"),
    ("_:ItemsView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ItemsView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ItemsView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Windows.Foundation.IInspectable"),
    ("_:ItemsView", "Loaded"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsView", "Loading"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Windows.Foundation.IInspectable"),
    ("_:ItemsView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ItemsView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ItemsView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ItemsView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ItemsView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ItemsView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ItemsView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ItemsView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ItemsView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsView", "DragOver"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ItemsView", "Drop"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ItemsView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ItemsView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsView", "Holding"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ItemsView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ItemsView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ItemsView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ItemsView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ItemsView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ItemsView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ItemsView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ItemsView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ItemsView", "Tapped"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ItemsView", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ItemsView", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ItemsView", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ItemsView", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ItemsWrapGrid", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Windows.Foundation.IInspectable"),
    ("_:ItemsWrapGrid", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ItemsWrapGrid", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ItemsWrapGrid", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Windows.Foundation.IInspectable"),
    ("_:ItemsWrapGrid", "Loaded"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsWrapGrid", "Loading"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Windows.Foundation.IInspectable"),
    ("_:ItemsWrapGrid", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ItemsWrapGrid", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsWrapGrid", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ItemsWrapGrid", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ItemsWrapGrid", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ItemsWrapGrid", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ItemsWrapGrid", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ItemsWrapGrid", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsWrapGrid", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ItemsWrapGrid", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ItemsWrapGrid", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsWrapGrid", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsWrapGrid", "DragOver"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsWrapGrid", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ItemsWrapGrid", "Drop"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ItemsWrapGrid", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ItemsWrapGrid", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ItemsWrapGrid", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsWrapGrid", "Holding"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ItemsWrapGrid", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsWrapGrid", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsWrapGrid", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ItemsWrapGrid", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsWrapGrid", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ItemsWrapGrid", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ItemsWrapGrid", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ItemsWrapGrid", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ItemsWrapGrid", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ItemsWrapGrid", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ItemsWrapGrid", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsWrapGrid", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsWrapGrid", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsWrapGrid", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsWrapGrid", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsWrapGrid", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsWrapGrid", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsWrapGrid", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ItemsWrapGrid", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsWrapGrid", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ItemsWrapGrid", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ItemsWrapGrid", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ItemsWrapGrid", "Tapped"): ("Microsoft.UI.Xaml.Controls.ItemsWrapGrid", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ListBox", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ListBox", "Windows.Foundation.IInspectable"),
    ("_:ListBox", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ListBox", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ListBox", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ListBox", "Windows.Foundation.IInspectable"),
    ("_:ListBox", "Loaded"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBox", "Loading"): ("Microsoft.UI.Xaml.Controls.ListBox", "Windows.Foundation.IInspectable"),
    ("_:ListBox", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ListBox", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBox", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ListBox", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ListBox", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ListBox", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ListBox", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ListBox", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBox", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ListBox", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ListBox", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListBox", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListBox", "DragOver"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListBox", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ListBox", "Drop"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListBox", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ListBox", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ListBox", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBox", "Holding"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ListBox", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListBox", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListBox", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ListBox", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBox", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ListBox", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ListBox", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ListBox", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ListBox", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ListBox", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ListBox", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBox", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBox", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBox", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBox", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBox", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBox", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBox", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBox", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListBox", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListBox", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBox", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ListBox", "Tapped"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ListBox", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ListBox", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ListBox", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ListBox", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.ListBox", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:ListBoxItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Windows.Foundation.IInspectable"),
    ("_:ListBoxItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ListBoxItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ListBoxItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Windows.Foundation.IInspectable"),
    ("_:ListBoxItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBoxItem", "Loading"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Windows.Foundation.IInspectable"),
    ("_:ListBoxItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ListBoxItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBoxItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ListBoxItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ListBoxItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ListBoxItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ListBoxItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ListBoxItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBoxItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ListBoxItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ListBoxItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListBoxItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListBoxItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListBoxItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ListBoxItem", "Drop"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListBoxItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ListBoxItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ListBoxItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBoxItem", "Holding"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ListBoxItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListBoxItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListBoxItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ListBoxItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBoxItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ListBoxItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ListBoxItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ListBoxItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ListBoxItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ListBoxItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ListBoxItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBoxItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBoxItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBoxItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBoxItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBoxItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBoxItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBoxItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListBoxItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListBoxItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListBoxItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListBoxItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ListBoxItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ListBoxItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ListBoxItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ListBoxItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ListBoxItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ListView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ListView", "Windows.Foundation.IInspectable"),
    ("_:ListView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ListView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ListView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ListView", "Windows.Foundation.IInspectable"),
    ("_:ListView", "Loaded"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListView", "Loading"): ("Microsoft.UI.Xaml.Controls.ListView", "Windows.Foundation.IInspectable"),
    ("_:ListView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ListView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ListView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ListView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ListView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ListView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ListView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ListView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ListView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListView", "DragOver"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ListView", "Drop"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ListView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ListView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListView", "Holding"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ListView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ListView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ListView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ListView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ListView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ListView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ListView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ListView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ListView", "Tapped"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ListView", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ListView", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ListView", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ListView", "DragItemsCompleted"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.DragItemsCompletedEventArgs"),
    ("_:ListView", "DragItemsStarting"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.DragItemsStartingEventArgs"),
    ("_:ListView", "ItemClick"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.ItemClickEventArgs"),
    ("_:ListView", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.ListView", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:ListViewBase", "DragItemsCompleted"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.DragItemsCompletedEventArgs"),
    ("_:ListViewBase", "DragItemsStarting"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.DragItemsStartingEventArgs"),
    ("_:ListViewBase", "ItemClick"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.ItemClickEventArgs"),
    ("_:ListViewBase", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Windows.Foundation.IInspectable"),
    ("_:ListViewBase", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ListViewBase", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ListViewBase", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Windows.Foundation.IInspectable"),
    ("_:ListViewBase", "Loaded"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBase", "Loading"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Windows.Foundation.IInspectable"),
    ("_:ListViewBase", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ListViewBase", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBase", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ListViewBase", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ListViewBase", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ListViewBase", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ListViewBase", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ListViewBase", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBase", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ListViewBase", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ListViewBase", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewBase", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewBase", "DragOver"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewBase", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ListViewBase", "Drop"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewBase", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ListViewBase", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ListViewBase", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBase", "Holding"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ListViewBase", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewBase", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewBase", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ListViewBase", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBase", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ListViewBase", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ListViewBase", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ListViewBase", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ListViewBase", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ListViewBase", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ListViewBase", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBase", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBase", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBase", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBase", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBase", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBase", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBase", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBase", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewBase", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewBase", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBase", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ListViewBase", "Tapped"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ListViewBase", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ListViewBase", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ListViewBase", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ListViewBase", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBase", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:ListViewBaseHeaderItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Windows.Foundation.IInspectable"),
    ("_:ListViewBaseHeaderItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ListViewBaseHeaderItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ListViewBaseHeaderItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Windows.Foundation.IInspectable"),
    ("_:ListViewBaseHeaderItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "Loading"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Windows.Foundation.IInspectable"),
    ("_:ListViewBaseHeaderItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ListViewBaseHeaderItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ListViewBaseHeaderItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ListViewBaseHeaderItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ListViewBaseHeaderItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ListViewBaseHeaderItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ListViewBaseHeaderItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewBaseHeaderItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewBaseHeaderItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewBaseHeaderItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ListViewBaseHeaderItem", "Drop"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewBaseHeaderItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ListViewBaseHeaderItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ListViewBaseHeaderItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "Holding"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ListViewBaseHeaderItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ListViewBaseHeaderItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ListViewBaseHeaderItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ListViewBaseHeaderItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ListViewBaseHeaderItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ListViewBaseHeaderItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ListViewHeaderItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Windows.Foundation.IInspectable"),
    ("_:ListViewHeaderItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ListViewHeaderItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ListViewHeaderItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Windows.Foundation.IInspectable"),
    ("_:ListViewHeaderItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewHeaderItem", "Loading"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Windows.Foundation.IInspectable"),
    ("_:ListViewHeaderItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ListViewHeaderItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewHeaderItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ListViewHeaderItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ListViewHeaderItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ListViewHeaderItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ListViewHeaderItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ListViewHeaderItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewHeaderItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ListViewHeaderItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ListViewHeaderItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewHeaderItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewHeaderItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewHeaderItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ListViewHeaderItem", "Drop"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewHeaderItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ListViewHeaderItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ListViewHeaderItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewHeaderItem", "Holding"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ListViewHeaderItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewHeaderItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewHeaderItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ListViewHeaderItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewHeaderItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ListViewHeaderItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ListViewHeaderItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ListViewHeaderItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ListViewHeaderItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ListViewHeaderItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ListViewHeaderItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewHeaderItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewHeaderItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewHeaderItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewHeaderItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewHeaderItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewHeaderItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewHeaderItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewHeaderItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewHeaderItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewHeaderItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewHeaderItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ListViewHeaderItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ListViewHeaderItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ListViewHeaderItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ListViewHeaderItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ListViewHeaderItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ListViewItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Windows.Foundation.IInspectable"),
    ("_:ListViewItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ListViewItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ListViewItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Windows.Foundation.IInspectable"),
    ("_:ListViewItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewItem", "Loading"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Windows.Foundation.IInspectable"),
    ("_:ListViewItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ListViewItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ListViewItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ListViewItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ListViewItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ListViewItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ListViewItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ListViewItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ListViewItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ListViewItem", "Drop"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ListViewItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ListViewItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ListViewItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewItem", "Holding"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ListViewItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ListViewItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ListViewItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ListViewItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ListViewItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ListViewItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ListViewItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ListViewItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ListViewItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ListViewItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ListViewItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ListViewItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ListViewItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ListViewItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ListViewItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ListViewItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:MediaPlayerElement", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Windows.Foundation.IInspectable"),
    ("_:MediaPlayerElement", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:MediaPlayerElement", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:MediaPlayerElement", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Windows.Foundation.IInspectable"),
    ("_:MediaPlayerElement", "Loaded"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaPlayerElement", "Loading"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Windows.Foundation.IInspectable"),
    ("_:MediaPlayerElement", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:MediaPlayerElement", "Unloaded"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaPlayerElement", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:MediaPlayerElement", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:MediaPlayerElement", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:MediaPlayerElement", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:MediaPlayerElement", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:MediaPlayerElement", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaPlayerElement", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:MediaPlayerElement", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:MediaPlayerElement", "DragEnter"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MediaPlayerElement", "DragLeave"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MediaPlayerElement", "DragOver"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MediaPlayerElement", "DragStarting"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:MediaPlayerElement", "Drop"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MediaPlayerElement", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:MediaPlayerElement", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:MediaPlayerElement", "GotFocus"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaPlayerElement", "Holding"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:MediaPlayerElement", "KeyDown"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MediaPlayerElement", "KeyUp"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MediaPlayerElement", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:MediaPlayerElement", "LostFocus"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaPlayerElement", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:MediaPlayerElement", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:MediaPlayerElement", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:MediaPlayerElement", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:MediaPlayerElement", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:MediaPlayerElement", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:MediaPlayerElement", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaPlayerElement", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaPlayerElement", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaPlayerElement", "PointerExited"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaPlayerElement", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaPlayerElement", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaPlayerElement", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaPlayerElement", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaPlayerElement", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MediaPlayerElement", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MediaPlayerElement", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaPlayerElement", "RightTapped"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:MediaPlayerElement", "Tapped"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:MediaPlayerElement", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:MediaPlayerElement", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:MediaPlayerElement", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.MediaPlayerElement", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:MediaTransportControls", "ThumbnailRequested"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Media.MediaTransportControlsThumbnailRequestedEventArgs"),
    ("_:MediaTransportControls", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Windows.Foundation.IInspectable"),
    ("_:MediaTransportControls", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:MediaTransportControls", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:MediaTransportControls", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Windows.Foundation.IInspectable"),
    ("_:MediaTransportControls", "Loaded"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaTransportControls", "Loading"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Windows.Foundation.IInspectable"),
    ("_:MediaTransportControls", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:MediaTransportControls", "Unloaded"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaTransportControls", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:MediaTransportControls", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:MediaTransportControls", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:MediaTransportControls", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:MediaTransportControls", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:MediaTransportControls", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaTransportControls", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:MediaTransportControls", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:MediaTransportControls", "DragEnter"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MediaTransportControls", "DragLeave"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MediaTransportControls", "DragOver"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MediaTransportControls", "DragStarting"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:MediaTransportControls", "Drop"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MediaTransportControls", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:MediaTransportControls", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:MediaTransportControls", "GotFocus"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaTransportControls", "Holding"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:MediaTransportControls", "KeyDown"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MediaTransportControls", "KeyUp"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MediaTransportControls", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:MediaTransportControls", "LostFocus"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaTransportControls", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:MediaTransportControls", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:MediaTransportControls", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:MediaTransportControls", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:MediaTransportControls", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:MediaTransportControls", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:MediaTransportControls", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaTransportControls", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaTransportControls", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaTransportControls", "PointerExited"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaTransportControls", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaTransportControls", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaTransportControls", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaTransportControls", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MediaTransportControls", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MediaTransportControls", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MediaTransportControls", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MediaTransportControls", "RightTapped"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:MediaTransportControls", "Tapped"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:MediaTransportControls", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:MediaTransportControls", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:MediaTransportControls", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.MediaTransportControls", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:MenuBar", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Windows.Foundation.IInspectable"),
    ("_:MenuBar", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:MenuBar", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:MenuBar", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Windows.Foundation.IInspectable"),
    ("_:MenuBar", "Loaded"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBar", "Loading"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Windows.Foundation.IInspectable"),
    ("_:MenuBar", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:MenuBar", "Unloaded"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBar", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:MenuBar", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:MenuBar", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:MenuBar", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:MenuBar", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:MenuBar", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBar", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:MenuBar", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:MenuBar", "DragEnter"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuBar", "DragLeave"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuBar", "DragOver"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuBar", "DragStarting"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:MenuBar", "Drop"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuBar", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:MenuBar", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:MenuBar", "GotFocus"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBar", "Holding"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:MenuBar", "KeyDown"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuBar", "KeyUp"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuBar", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:MenuBar", "LostFocus"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBar", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:MenuBar", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:MenuBar", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:MenuBar", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:MenuBar", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:MenuBar", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:MenuBar", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBar", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBar", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBar", "PointerExited"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBar", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBar", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBar", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBar", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBar", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuBar", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuBar", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBar", "RightTapped"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:MenuBar", "Tapped"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:MenuBar", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:MenuBar", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:MenuBar", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.MenuBar", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:MenuBarItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Windows.Foundation.IInspectable"),
    ("_:MenuBarItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:MenuBarItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:MenuBarItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Windows.Foundation.IInspectable"),
    ("_:MenuBarItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBarItem", "Loading"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Windows.Foundation.IInspectable"),
    ("_:MenuBarItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:MenuBarItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBarItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:MenuBarItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:MenuBarItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:MenuBarItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:MenuBarItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:MenuBarItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBarItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:MenuBarItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:MenuBarItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuBarItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuBarItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuBarItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:MenuBarItem", "Drop"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuBarItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:MenuBarItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:MenuBarItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBarItem", "Holding"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:MenuBarItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuBarItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuBarItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:MenuBarItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBarItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:MenuBarItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:MenuBarItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:MenuBarItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:MenuBarItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:MenuBarItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:MenuBarItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBarItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBarItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBarItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBarItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBarItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBarItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBarItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuBarItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuBarItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuBarItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuBarItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:MenuBarItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:MenuBarItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:MenuBarItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:MenuBarItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.MenuBarItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:MenuFlyout", "Closed"): ("Microsoft.UI.Xaml.Controls.MenuFlyout", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyout", "Closing"): ("Microsoft.UI.Xaml.Controls.MenuFlyout", "Microsoft.UI.Xaml.Controls.FlyoutBaseClosingEventArgs"),
    ("_:MenuFlyout", "Opened"): ("Microsoft.UI.Xaml.Controls.MenuFlyout", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyout", "Opening"): ("Microsoft.UI.Xaml.Controls.MenuFlyout", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyoutItem", "Click"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyoutItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:MenuFlyoutItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:MenuFlyoutItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyoutItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItem", "Loading"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyoutItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:MenuFlyoutItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:MenuFlyoutItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:MenuFlyoutItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:MenuFlyoutItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:MenuFlyoutItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:MenuFlyoutItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:MenuFlyoutItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:MenuFlyoutItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:MenuFlyoutItem", "Drop"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:MenuFlyoutItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:MenuFlyoutItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItem", "Holding"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:MenuFlyoutItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:MenuFlyoutItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:MenuFlyoutItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:MenuFlyoutItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:MenuFlyoutItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:MenuFlyoutItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:MenuFlyoutItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:MenuFlyoutItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:MenuFlyoutItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:MenuFlyoutItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:MenuFlyoutItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:MenuFlyoutItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:MenuFlyoutItemBase", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyoutItemBase", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:MenuFlyoutItemBase", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:MenuFlyoutItemBase", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyoutItemBase", "Loaded"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "Loading"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyoutItemBase", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:MenuFlyoutItemBase", "Unloaded"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:MenuFlyoutItemBase", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:MenuFlyoutItemBase", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:MenuFlyoutItemBase", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:MenuFlyoutItemBase", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:MenuFlyoutItemBase", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "DragEnter"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutItemBase", "DragLeave"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutItemBase", "DragOver"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutItemBase", "DragStarting"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:MenuFlyoutItemBase", "Drop"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutItemBase", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:MenuFlyoutItemBase", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:MenuFlyoutItemBase", "GotFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "Holding"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:MenuFlyoutItemBase", "KeyDown"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "KeyUp"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:MenuFlyoutItemBase", "LostFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:MenuFlyoutItemBase", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "PointerExited"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "RightTapped"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "Tapped"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:MenuFlyoutItemBase", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:MenuFlyoutItemBase", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:MenuFlyoutItemBase", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:MenuFlyoutSubItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyoutSubItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:MenuFlyoutSubItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:MenuFlyoutSubItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyoutSubItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "Loading"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Windows.Foundation.IInspectable"),
    ("_:MenuFlyoutSubItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:MenuFlyoutSubItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:MenuFlyoutSubItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:MenuFlyoutSubItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:MenuFlyoutSubItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:MenuFlyoutSubItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:MenuFlyoutSubItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutSubItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutSubItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutSubItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:MenuFlyoutSubItem", "Drop"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:MenuFlyoutSubItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:MenuFlyoutSubItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:MenuFlyoutSubItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "Holding"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:MenuFlyoutSubItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:MenuFlyoutSubItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:MenuFlyoutSubItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:MenuFlyoutSubItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:MenuFlyoutSubItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:MenuFlyoutSubItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:NavigationView", "BackRequested"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.NavigationViewBackRequestedEventArgs"),
    ("_:NavigationView", "Collapsed"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.NavigationViewItemCollapsedEventArgs"),
    ("_:NavigationView", "DisplayModeChanged"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.NavigationViewDisplayModeChangedEventArgs"),
    ("_:NavigationView", "Expanding"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.NavigationViewItemExpandingEventArgs"),
    ("_:NavigationView", "ItemInvoked"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs"),
    ("_:NavigationView", "PaneClosed"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Windows.Foundation.IInspectable"),
    ("_:NavigationView", "PaneClosing"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.NavigationViewPaneClosingEventArgs"),
    ("_:NavigationView", "PaneOpened"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Windows.Foundation.IInspectable"),
    ("_:NavigationView", "PaneOpening"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Windows.Foundation.IInspectable"),
    ("_:NavigationView", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.NavigationViewSelectionChangedEventArgs"),
    ("_:NavigationView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Windows.Foundation.IInspectable"),
    ("_:NavigationView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:NavigationView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:NavigationView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Windows.Foundation.IInspectable"),
    ("_:NavigationView", "Loaded"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationView", "Loading"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Windows.Foundation.IInspectable"),
    ("_:NavigationView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:NavigationView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:NavigationView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:NavigationView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:NavigationView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:NavigationView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:NavigationView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:NavigationView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:NavigationView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationView", "DragOver"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:NavigationView", "Drop"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:NavigationView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:NavigationView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationView", "Holding"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:NavigationView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:NavigationView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:NavigationView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:NavigationView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:NavigationView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:NavigationView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:NavigationView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:NavigationView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:NavigationView", "Tapped"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:NavigationView", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:NavigationView", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:NavigationView", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.NavigationView", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:NavigationViewItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Windows.Foundation.IInspectable"),
    ("_:NavigationViewItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:NavigationViewItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:NavigationViewItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Windows.Foundation.IInspectable"),
    ("_:NavigationViewItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItem", "Loading"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Windows.Foundation.IInspectable"),
    ("_:NavigationViewItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:NavigationViewItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:NavigationViewItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:NavigationViewItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:NavigationViewItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:NavigationViewItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:NavigationViewItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:NavigationViewItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:NavigationViewItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationViewItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationViewItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationViewItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:NavigationViewItem", "Drop"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationViewItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:NavigationViewItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:NavigationViewItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItem", "Holding"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:NavigationViewItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationViewItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationViewItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:NavigationViewItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:NavigationViewItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:NavigationViewItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:NavigationViewItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:NavigationViewItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:NavigationViewItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:NavigationViewItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationViewItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationViewItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:NavigationViewItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:NavigationViewItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:NavigationViewItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:NavigationViewItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:NavigationViewItemBase", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Windows.Foundation.IInspectable"),
    ("_:NavigationViewItemBase", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:NavigationViewItemBase", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:NavigationViewItemBase", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Windows.Foundation.IInspectable"),
    ("_:NavigationViewItemBase", "Loaded"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItemBase", "Loading"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Windows.Foundation.IInspectable"),
    ("_:NavigationViewItemBase", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:NavigationViewItemBase", "Unloaded"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItemBase", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:NavigationViewItemBase", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:NavigationViewItemBase", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:NavigationViewItemBase", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:NavigationViewItemBase", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:NavigationViewItemBase", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItemBase", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:NavigationViewItemBase", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:NavigationViewItemBase", "DragEnter"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationViewItemBase", "DragLeave"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationViewItemBase", "DragOver"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationViewItemBase", "DragStarting"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:NavigationViewItemBase", "Drop"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NavigationViewItemBase", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:NavigationViewItemBase", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:NavigationViewItemBase", "GotFocus"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItemBase", "Holding"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:NavigationViewItemBase", "KeyDown"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationViewItemBase", "KeyUp"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationViewItemBase", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:NavigationViewItemBase", "LostFocus"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItemBase", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:NavigationViewItemBase", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:NavigationViewItemBase", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:NavigationViewItemBase", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:NavigationViewItemBase", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:NavigationViewItemBase", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:NavigationViewItemBase", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItemBase", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItemBase", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItemBase", "PointerExited"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItemBase", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItemBase", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItemBase", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItemBase", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NavigationViewItemBase", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationViewItemBase", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NavigationViewItemBase", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NavigationViewItemBase", "RightTapped"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:NavigationViewItemBase", "Tapped"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:NavigationViewItemBase", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:NavigationViewItemBase", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:NavigationViewItemBase", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.NavigationViewItemBase", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:NumberBox", "ValueChanged"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.NumberBoxValueChangedEventArgs"),
    ("_:NumberBox", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Windows.Foundation.IInspectable"),
    ("_:NumberBox", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:NumberBox", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:NumberBox", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Windows.Foundation.IInspectable"),
    ("_:NumberBox", "Loaded"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NumberBox", "Loading"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Windows.Foundation.IInspectable"),
    ("_:NumberBox", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:NumberBox", "Unloaded"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NumberBox", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:NumberBox", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:NumberBox", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:NumberBox", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:NumberBox", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:NumberBox", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NumberBox", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:NumberBox", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:NumberBox", "DragEnter"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NumberBox", "DragLeave"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NumberBox", "DragOver"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NumberBox", "DragStarting"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:NumberBox", "Drop"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:NumberBox", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:NumberBox", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:NumberBox", "GotFocus"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NumberBox", "Holding"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:NumberBox", "KeyDown"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NumberBox", "KeyUp"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NumberBox", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:NumberBox", "LostFocus"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NumberBox", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:NumberBox", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:NumberBox", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:NumberBox", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:NumberBox", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:NumberBox", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:NumberBox", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NumberBox", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NumberBox", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NumberBox", "PointerExited"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NumberBox", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NumberBox", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NumberBox", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NumberBox", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:NumberBox", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NumberBox", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:NumberBox", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:NumberBox", "RightTapped"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:NumberBox", "Tapped"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:NumberBox", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:NumberBox", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:NumberBox", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.NumberBox", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Page", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Page", "Windows.Foundation.IInspectable"),
    ("_:Page", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Page", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Page", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Page", "Windows.Foundation.IInspectable"),
    ("_:Page", "Loaded"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Page", "Loading"): ("Microsoft.UI.Xaml.Controls.Page", "Windows.Foundation.IInspectable"),
    ("_:Page", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Page", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Page", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Page", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Page", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Page", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Page", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Page", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Page", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Page", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Page", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Page", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Page", "DragOver"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Page", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Page", "Drop"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Page", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Page", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Page", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Page", "Holding"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Page", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Page", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Page", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Page", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Page", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Page", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Page", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Page", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Page", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Page", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Page", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Page", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Page", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Page", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Page", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Page", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Page", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Page", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Page", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Page", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Page", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Page", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Page", "Tapped"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Page", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:Page", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:Page", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Page", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Panel", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Panel", "Windows.Foundation.IInspectable"),
    ("_:Panel", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Panel", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Panel", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Panel", "Windows.Foundation.IInspectable"),
    ("_:Panel", "Loaded"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Panel", "Loading"): ("Microsoft.UI.Xaml.Controls.Panel", "Windows.Foundation.IInspectable"),
    ("_:Panel", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Panel", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Panel", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Panel", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Panel", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Panel", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Panel", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Panel", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Panel", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Panel", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Panel", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Panel", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Panel", "DragOver"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Panel", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Panel", "Drop"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Panel", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Panel", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Panel", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Panel", "Holding"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Panel", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Panel", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Panel", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Panel", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Panel", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Panel", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Panel", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Panel", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Panel", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Panel", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Panel", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Panel", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Panel", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Panel", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Panel", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Panel", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Panel", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Panel", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Panel", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Panel", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Panel", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Panel", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Panel", "Tapped"): ("Microsoft.UI.Xaml.Controls.Panel", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ParallaxView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Windows.Foundation.IInspectable"),
    ("_:ParallaxView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ParallaxView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ParallaxView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Windows.Foundation.IInspectable"),
    ("_:ParallaxView", "Loaded"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ParallaxView", "Loading"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Windows.Foundation.IInspectable"),
    ("_:ParallaxView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ParallaxView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ParallaxView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ParallaxView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ParallaxView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ParallaxView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ParallaxView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ParallaxView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ParallaxView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ParallaxView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ParallaxView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ParallaxView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ParallaxView", "DragOver"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ParallaxView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ParallaxView", "Drop"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ParallaxView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ParallaxView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ParallaxView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ParallaxView", "Holding"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ParallaxView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ParallaxView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ParallaxView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ParallaxView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ParallaxView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ParallaxView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ParallaxView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ParallaxView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ParallaxView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ParallaxView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ParallaxView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ParallaxView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ParallaxView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ParallaxView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ParallaxView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ParallaxView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ParallaxView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ParallaxView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ParallaxView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ParallaxView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ParallaxView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ParallaxView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ParallaxView", "Tapped"): ("Microsoft.UI.Xaml.Controls.ParallaxView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:PasswordBox", "PasswordChanged"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PasswordBox", "PasswordChanging"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.PasswordBoxPasswordChangingEventArgs"),
    ("_:PasswordBox", "Paste"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.TextControlPasteEventArgs"),
    ("_:PasswordBox", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Windows.Foundation.IInspectable"),
    ("_:PasswordBox", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:PasswordBox", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:PasswordBox", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Windows.Foundation.IInspectable"),
    ("_:PasswordBox", "Loaded"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PasswordBox", "Loading"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Windows.Foundation.IInspectable"),
    ("_:PasswordBox", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:PasswordBox", "Unloaded"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PasswordBox", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:PasswordBox", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:PasswordBox", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:PasswordBox", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:PasswordBox", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:PasswordBox", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PasswordBox", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:PasswordBox", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:PasswordBox", "DragEnter"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PasswordBox", "DragLeave"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PasswordBox", "DragOver"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PasswordBox", "DragStarting"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:PasswordBox", "Drop"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PasswordBox", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:PasswordBox", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:PasswordBox", "GotFocus"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PasswordBox", "Holding"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:PasswordBox", "KeyDown"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PasswordBox", "KeyUp"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PasswordBox", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:PasswordBox", "LostFocus"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PasswordBox", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:PasswordBox", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:PasswordBox", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:PasswordBox", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:PasswordBox", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:PasswordBox", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:PasswordBox", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PasswordBox", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PasswordBox", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PasswordBox", "PointerExited"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PasswordBox", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PasswordBox", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PasswordBox", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PasswordBox", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PasswordBox", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PasswordBox", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PasswordBox", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PasswordBox", "RightTapped"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:PasswordBox", "Tapped"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:PasswordBox", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:PasswordBox", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:PasswordBox", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.PasswordBox", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:PathIcon", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Windows.Foundation.IInspectable"),
    ("_:PathIcon", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:PathIcon", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:PathIcon", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Windows.Foundation.IInspectable"),
    ("_:PathIcon", "Loaded"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PathIcon", "Loading"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Windows.Foundation.IInspectable"),
    ("_:PathIcon", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:PathIcon", "Unloaded"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PathIcon", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:PathIcon", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:PathIcon", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:PathIcon", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:PathIcon", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:PathIcon", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PathIcon", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:PathIcon", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:PathIcon", "DragEnter"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PathIcon", "DragLeave"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PathIcon", "DragOver"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PathIcon", "DragStarting"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:PathIcon", "Drop"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PathIcon", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:PathIcon", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:PathIcon", "GotFocus"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PathIcon", "Holding"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:PathIcon", "KeyDown"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PathIcon", "KeyUp"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PathIcon", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:PathIcon", "LostFocus"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PathIcon", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:PathIcon", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:PathIcon", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:PathIcon", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:PathIcon", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:PathIcon", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:PathIcon", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PathIcon", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PathIcon", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PathIcon", "PointerExited"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PathIcon", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PathIcon", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PathIcon", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PathIcon", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PathIcon", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PathIcon", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PathIcon", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PathIcon", "RightTapped"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:PathIcon", "Tapped"): ("Microsoft.UI.Xaml.Controls.PathIcon", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:PersonPicture", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Windows.Foundation.IInspectable"),
    ("_:PersonPicture", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:PersonPicture", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:PersonPicture", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Windows.Foundation.IInspectable"),
    ("_:PersonPicture", "Loaded"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PersonPicture", "Loading"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Windows.Foundation.IInspectable"),
    ("_:PersonPicture", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:PersonPicture", "Unloaded"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PersonPicture", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:PersonPicture", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:PersonPicture", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:PersonPicture", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:PersonPicture", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:PersonPicture", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PersonPicture", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:PersonPicture", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:PersonPicture", "DragEnter"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PersonPicture", "DragLeave"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PersonPicture", "DragOver"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PersonPicture", "DragStarting"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:PersonPicture", "Drop"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PersonPicture", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:PersonPicture", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:PersonPicture", "GotFocus"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PersonPicture", "Holding"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:PersonPicture", "KeyDown"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PersonPicture", "KeyUp"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PersonPicture", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:PersonPicture", "LostFocus"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PersonPicture", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:PersonPicture", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:PersonPicture", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:PersonPicture", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:PersonPicture", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:PersonPicture", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:PersonPicture", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PersonPicture", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PersonPicture", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PersonPicture", "PointerExited"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PersonPicture", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PersonPicture", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PersonPicture", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PersonPicture", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PersonPicture", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PersonPicture", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PersonPicture", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PersonPicture", "RightTapped"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:PersonPicture", "Tapped"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:PersonPicture", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:PersonPicture", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:PersonPicture", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.PersonPicture", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:PipsPager", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Windows.Foundation.IInspectable"),
    ("_:PipsPager", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:PipsPager", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:PipsPager", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Windows.Foundation.IInspectable"),
    ("_:PipsPager", "Loaded"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PipsPager", "Loading"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Windows.Foundation.IInspectable"),
    ("_:PipsPager", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:PipsPager", "Unloaded"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PipsPager", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:PipsPager", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:PipsPager", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:PipsPager", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:PipsPager", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:PipsPager", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PipsPager", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:PipsPager", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:PipsPager", "DragEnter"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PipsPager", "DragLeave"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PipsPager", "DragOver"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PipsPager", "DragStarting"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:PipsPager", "Drop"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PipsPager", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:PipsPager", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:PipsPager", "GotFocus"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PipsPager", "Holding"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:PipsPager", "KeyDown"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PipsPager", "KeyUp"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PipsPager", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:PipsPager", "LostFocus"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PipsPager", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:PipsPager", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:PipsPager", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:PipsPager", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:PipsPager", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:PipsPager", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:PipsPager", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PipsPager", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PipsPager", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PipsPager", "PointerExited"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PipsPager", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PipsPager", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PipsPager", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PipsPager", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PipsPager", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PipsPager", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PipsPager", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PipsPager", "RightTapped"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:PipsPager", "Tapped"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:PipsPager", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:PipsPager", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:PipsPager", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.PipsPager", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Pivot", "PivotItemLoaded"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.PivotItemEventArgs"),
    ("_:Pivot", "PivotItemLoading"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.PivotItemEventArgs"),
    ("_:Pivot", "PivotItemUnloaded"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.PivotItemEventArgs"),
    ("_:Pivot", "PivotItemUnloading"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.PivotItemEventArgs"),
    ("_:Pivot", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:Pivot", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Pivot", "Windows.Foundation.IInspectable"),
    ("_:Pivot", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Pivot", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Pivot", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Pivot", "Windows.Foundation.IInspectable"),
    ("_:Pivot", "Loaded"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Pivot", "Loading"): ("Microsoft.UI.Xaml.Controls.Pivot", "Windows.Foundation.IInspectable"),
    ("_:Pivot", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Pivot", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Pivot", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Pivot", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Pivot", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Pivot", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Pivot", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Pivot", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Pivot", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Pivot", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Pivot", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Pivot", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Pivot", "DragOver"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Pivot", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Pivot", "Drop"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Pivot", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Pivot", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Pivot", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Pivot", "Holding"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Pivot", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Pivot", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Pivot", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Pivot", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Pivot", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Pivot", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Pivot", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Pivot", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Pivot", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Pivot", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Pivot", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Pivot", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Pivot", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Pivot", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Pivot", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Pivot", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Pivot", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Pivot", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Pivot", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Pivot", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Pivot", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Pivot", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Pivot", "Tapped"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Pivot", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:Pivot", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:Pivot", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Pivot", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:PivotItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Windows.Foundation.IInspectable"),
    ("_:PivotItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:PivotItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:PivotItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Windows.Foundation.IInspectable"),
    ("_:PivotItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PivotItem", "Loading"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Windows.Foundation.IInspectable"),
    ("_:PivotItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:PivotItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PivotItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:PivotItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:PivotItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:PivotItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:PivotItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:PivotItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PivotItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:PivotItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:PivotItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PivotItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PivotItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PivotItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:PivotItem", "Drop"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:PivotItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:PivotItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:PivotItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PivotItem", "Holding"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:PivotItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PivotItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PivotItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:PivotItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PivotItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:PivotItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:PivotItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:PivotItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:PivotItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:PivotItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:PivotItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PivotItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PivotItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PivotItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PivotItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PivotItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PivotItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PivotItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:PivotItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PivotItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:PivotItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:PivotItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:PivotItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:PivotItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:PivotItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:PivotItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.PivotItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ProgressBar", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Windows.Foundation.IInspectable"),
    ("_:ProgressBar", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ProgressBar", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ProgressBar", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Windows.Foundation.IInspectable"),
    ("_:ProgressBar", "Loaded"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressBar", "Loading"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Windows.Foundation.IInspectable"),
    ("_:ProgressBar", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ProgressBar", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressBar", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ProgressBar", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ProgressBar", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ProgressBar", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ProgressBar", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ProgressBar", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressBar", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ProgressBar", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ProgressBar", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ProgressBar", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ProgressBar", "DragOver"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ProgressBar", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ProgressBar", "Drop"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ProgressBar", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ProgressBar", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ProgressBar", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressBar", "Holding"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ProgressBar", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ProgressBar", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ProgressBar", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ProgressBar", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressBar", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ProgressBar", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ProgressBar", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ProgressBar", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ProgressBar", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ProgressBar", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ProgressBar", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressBar", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressBar", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressBar", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressBar", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressBar", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressBar", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressBar", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressBar", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ProgressBar", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ProgressBar", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressBar", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ProgressBar", "Tapped"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ProgressBar", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ProgressBar", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ProgressBar", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ProgressBar", "ValueChanged"): ("Microsoft.UI.Xaml.Controls.ProgressBar", "Microsoft.UI.Xaml.Controls.RangeBaseValueChangedEventArgs"),
    ("_:ProgressRing", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Windows.Foundation.IInspectable"),
    ("_:ProgressRing", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ProgressRing", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ProgressRing", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Windows.Foundation.IInspectable"),
    ("_:ProgressRing", "Loaded"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressRing", "Loading"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Windows.Foundation.IInspectable"),
    ("_:ProgressRing", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ProgressRing", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressRing", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ProgressRing", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ProgressRing", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ProgressRing", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ProgressRing", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ProgressRing", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressRing", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ProgressRing", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ProgressRing", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ProgressRing", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ProgressRing", "DragOver"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ProgressRing", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ProgressRing", "Drop"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ProgressRing", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ProgressRing", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ProgressRing", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressRing", "Holding"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ProgressRing", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ProgressRing", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ProgressRing", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ProgressRing", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressRing", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ProgressRing", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ProgressRing", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ProgressRing", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ProgressRing", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ProgressRing", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ProgressRing", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressRing", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressRing", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressRing", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressRing", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressRing", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressRing", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressRing", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ProgressRing", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ProgressRing", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ProgressRing", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ProgressRing", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ProgressRing", "Tapped"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ProgressRing", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ProgressRing", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ProgressRing", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ProgressRing", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:RadioButton", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Windows.Foundation.IInspectable"),
    ("_:RadioButton", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:RadioButton", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:RadioButton", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Windows.Foundation.IInspectable"),
    ("_:RadioButton", "Loaded"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButton", "Loading"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Windows.Foundation.IInspectable"),
    ("_:RadioButton", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:RadioButton", "Unloaded"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButton", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RadioButton", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RadioButton", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RadioButton", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:RadioButton", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RadioButton", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButton", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RadioButton", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RadioButton", "DragEnter"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioButton", "DragLeave"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioButton", "DragOver"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioButton", "DragStarting"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:RadioButton", "Drop"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioButton", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:RadioButton", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RadioButton", "GotFocus"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButton", "Holding"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RadioButton", "KeyDown"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioButton", "KeyUp"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioButton", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RadioButton", "LostFocus"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButton", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RadioButton", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RadioButton", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RadioButton", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RadioButton", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RadioButton", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RadioButton", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButton", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButton", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButton", "PointerExited"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButton", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButton", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButton", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButton", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButton", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioButton", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioButton", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButton", "RightTapped"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RadioButton", "Tapped"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:RadioButton", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:RadioButton", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:RadioButton", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:RadioButton", "Click"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButton", "Checked"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButton", "Indeterminate"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButton", "Unchecked"): ("Microsoft.UI.Xaml.Controls.RadioButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButtons", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:RadioButtons", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Windows.Foundation.IInspectable"),
    ("_:RadioButtons", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:RadioButtons", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:RadioButtons", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Windows.Foundation.IInspectable"),
    ("_:RadioButtons", "Loaded"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButtons", "Loading"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Windows.Foundation.IInspectable"),
    ("_:RadioButtons", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:RadioButtons", "Unloaded"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButtons", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RadioButtons", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RadioButtons", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RadioButtons", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:RadioButtons", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RadioButtons", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButtons", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RadioButtons", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RadioButtons", "DragEnter"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioButtons", "DragLeave"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioButtons", "DragOver"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioButtons", "DragStarting"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:RadioButtons", "Drop"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioButtons", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:RadioButtons", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RadioButtons", "GotFocus"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButtons", "Holding"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RadioButtons", "KeyDown"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioButtons", "KeyUp"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioButtons", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RadioButtons", "LostFocus"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButtons", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RadioButtons", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RadioButtons", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RadioButtons", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RadioButtons", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RadioButtons", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RadioButtons", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButtons", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButtons", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButtons", "PointerExited"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButtons", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButtons", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButtons", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButtons", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioButtons", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioButtons", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioButtons", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioButtons", "RightTapped"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RadioButtons", "Tapped"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:RadioButtons", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:RadioButtons", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:RadioButtons", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.RadioButtons", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:RadioMenuFlyoutItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Windows.Foundation.IInspectable"),
    ("_:RadioMenuFlyoutItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:RadioMenuFlyoutItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:RadioMenuFlyoutItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Windows.Foundation.IInspectable"),
    ("_:RadioMenuFlyoutItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "Loading"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Windows.Foundation.IInspectable"),
    ("_:RadioMenuFlyoutItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:RadioMenuFlyoutItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RadioMenuFlyoutItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RadioMenuFlyoutItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RadioMenuFlyoutItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:RadioMenuFlyoutItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RadioMenuFlyoutItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioMenuFlyoutItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioMenuFlyoutItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioMenuFlyoutItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:RadioMenuFlyoutItem", "Drop"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RadioMenuFlyoutItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:RadioMenuFlyoutItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RadioMenuFlyoutItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "Holding"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RadioMenuFlyoutItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RadioMenuFlyoutItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RadioMenuFlyoutItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:RadioMenuFlyoutItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:RadioMenuFlyoutItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:RadioMenuFlyoutItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:RadioMenuFlyoutItem", "Click"): ("Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RatingControl", "ValueChanged"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Windows.Foundation.IInspectable"),
    ("_:RatingControl", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Windows.Foundation.IInspectable"),
    ("_:RatingControl", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:RatingControl", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:RatingControl", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Windows.Foundation.IInspectable"),
    ("_:RatingControl", "Loaded"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RatingControl", "Loading"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Windows.Foundation.IInspectable"),
    ("_:RatingControl", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:RatingControl", "Unloaded"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RatingControl", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RatingControl", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RatingControl", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RatingControl", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:RatingControl", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RatingControl", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RatingControl", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RatingControl", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RatingControl", "DragEnter"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RatingControl", "DragLeave"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RatingControl", "DragOver"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RatingControl", "DragStarting"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:RatingControl", "Drop"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RatingControl", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:RatingControl", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RatingControl", "GotFocus"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RatingControl", "Holding"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RatingControl", "KeyDown"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RatingControl", "KeyUp"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RatingControl", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RatingControl", "LostFocus"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RatingControl", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RatingControl", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RatingControl", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RatingControl", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RatingControl", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RatingControl", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RatingControl", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RatingControl", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RatingControl", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RatingControl", "PointerExited"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RatingControl", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RatingControl", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RatingControl", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RatingControl", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RatingControl", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RatingControl", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RatingControl", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RatingControl", "RightTapped"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RatingControl", "Tapped"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:RatingControl", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:RatingControl", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:RatingControl", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.RatingControl", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:RefreshContainer", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Windows.Foundation.IInspectable"),
    ("_:RefreshContainer", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:RefreshContainer", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:RefreshContainer", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Windows.Foundation.IInspectable"),
    ("_:RefreshContainer", "Loaded"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshContainer", "Loading"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Windows.Foundation.IInspectable"),
    ("_:RefreshContainer", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:RefreshContainer", "Unloaded"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshContainer", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RefreshContainer", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RefreshContainer", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RefreshContainer", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:RefreshContainer", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RefreshContainer", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshContainer", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RefreshContainer", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RefreshContainer", "DragEnter"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RefreshContainer", "DragLeave"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RefreshContainer", "DragOver"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RefreshContainer", "DragStarting"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:RefreshContainer", "Drop"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RefreshContainer", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:RefreshContainer", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RefreshContainer", "GotFocus"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshContainer", "Holding"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RefreshContainer", "KeyDown"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RefreshContainer", "KeyUp"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RefreshContainer", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RefreshContainer", "LostFocus"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshContainer", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RefreshContainer", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RefreshContainer", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RefreshContainer", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RefreshContainer", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RefreshContainer", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RefreshContainer", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshContainer", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshContainer", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshContainer", "PointerExited"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshContainer", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshContainer", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshContainer", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshContainer", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshContainer", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RefreshContainer", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RefreshContainer", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshContainer", "RightTapped"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RefreshContainer", "Tapped"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:RefreshContainer", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:RefreshContainer", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:RefreshContainer", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.RefreshContainer", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:RefreshVisualizer", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Windows.Foundation.IInspectable"),
    ("_:RefreshVisualizer", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:RefreshVisualizer", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:RefreshVisualizer", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Windows.Foundation.IInspectable"),
    ("_:RefreshVisualizer", "Loaded"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshVisualizer", "Loading"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Windows.Foundation.IInspectable"),
    ("_:RefreshVisualizer", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:RefreshVisualizer", "Unloaded"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshVisualizer", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RefreshVisualizer", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RefreshVisualizer", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RefreshVisualizer", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:RefreshVisualizer", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RefreshVisualizer", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshVisualizer", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RefreshVisualizer", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RefreshVisualizer", "DragEnter"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RefreshVisualizer", "DragLeave"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RefreshVisualizer", "DragOver"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RefreshVisualizer", "DragStarting"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:RefreshVisualizer", "Drop"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RefreshVisualizer", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:RefreshVisualizer", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RefreshVisualizer", "GotFocus"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshVisualizer", "Holding"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RefreshVisualizer", "KeyDown"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RefreshVisualizer", "KeyUp"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RefreshVisualizer", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RefreshVisualizer", "LostFocus"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshVisualizer", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RefreshVisualizer", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RefreshVisualizer", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RefreshVisualizer", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RefreshVisualizer", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RefreshVisualizer", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RefreshVisualizer", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshVisualizer", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshVisualizer", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshVisualizer", "PointerExited"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshVisualizer", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshVisualizer", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshVisualizer", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshVisualizer", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RefreshVisualizer", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RefreshVisualizer", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RefreshVisualizer", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RefreshVisualizer", "RightTapped"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RefreshVisualizer", "Tapped"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:RefreshVisualizer", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:RefreshVisualizer", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:RefreshVisualizer", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.RefreshVisualizer", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:RelativePanel", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Windows.Foundation.IInspectable"),
    ("_:RelativePanel", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:RelativePanel", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:RelativePanel", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Windows.Foundation.IInspectable"),
    ("_:RelativePanel", "Loaded"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RelativePanel", "Loading"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Windows.Foundation.IInspectable"),
    ("_:RelativePanel", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:RelativePanel", "Unloaded"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RelativePanel", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RelativePanel", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RelativePanel", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RelativePanel", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:RelativePanel", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RelativePanel", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RelativePanel", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RelativePanel", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RelativePanel", "DragEnter"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RelativePanel", "DragLeave"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RelativePanel", "DragOver"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RelativePanel", "DragStarting"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:RelativePanel", "Drop"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RelativePanel", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:RelativePanel", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RelativePanel", "GotFocus"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RelativePanel", "Holding"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RelativePanel", "KeyDown"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RelativePanel", "KeyUp"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RelativePanel", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RelativePanel", "LostFocus"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RelativePanel", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RelativePanel", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RelativePanel", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RelativePanel", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RelativePanel", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RelativePanel", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RelativePanel", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RelativePanel", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RelativePanel", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RelativePanel", "PointerExited"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RelativePanel", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RelativePanel", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RelativePanel", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RelativePanel", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RelativePanel", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RelativePanel", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RelativePanel", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RelativePanel", "RightTapped"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RelativePanel", "Tapped"): ("Microsoft.UI.Xaml.Controls.RelativePanel", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:RichEditBox", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Windows.Foundation.IInspectable"),
    ("_:RichEditBox", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:RichEditBox", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:RichEditBox", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Windows.Foundation.IInspectable"),
    ("_:RichEditBox", "Loaded"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichEditBox", "Loading"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Windows.Foundation.IInspectable"),
    ("_:RichEditBox", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:RichEditBox", "Unloaded"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichEditBox", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RichEditBox", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RichEditBox", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RichEditBox", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:RichEditBox", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RichEditBox", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichEditBox", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RichEditBox", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RichEditBox", "DragEnter"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichEditBox", "DragLeave"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichEditBox", "DragOver"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichEditBox", "DragStarting"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:RichEditBox", "Drop"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichEditBox", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:RichEditBox", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RichEditBox", "GotFocus"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichEditBox", "Holding"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RichEditBox", "KeyDown"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichEditBox", "KeyUp"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichEditBox", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RichEditBox", "LostFocus"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichEditBox", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RichEditBox", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RichEditBox", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RichEditBox", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RichEditBox", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RichEditBox", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RichEditBox", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichEditBox", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichEditBox", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichEditBox", "PointerExited"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichEditBox", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichEditBox", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichEditBox", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichEditBox", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichEditBox", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichEditBox", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichEditBox", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichEditBox", "RightTapped"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RichEditBox", "Tapped"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:RichEditBox", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:RichEditBox", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:RichEditBox", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.RichEditBox", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:RichTextBlock", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Windows.Foundation.IInspectable"),
    ("_:RichTextBlock", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:RichTextBlock", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:RichTextBlock", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Windows.Foundation.IInspectable"),
    ("_:RichTextBlock", "Loaded"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlock", "Loading"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Windows.Foundation.IInspectable"),
    ("_:RichTextBlock", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:RichTextBlock", "Unloaded"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlock", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RichTextBlock", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RichTextBlock", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RichTextBlock", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:RichTextBlock", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RichTextBlock", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlock", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RichTextBlock", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RichTextBlock", "DragEnter"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichTextBlock", "DragLeave"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichTextBlock", "DragOver"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichTextBlock", "DragStarting"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:RichTextBlock", "Drop"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichTextBlock", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:RichTextBlock", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RichTextBlock", "GotFocus"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlock", "Holding"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RichTextBlock", "KeyDown"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichTextBlock", "KeyUp"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichTextBlock", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RichTextBlock", "LostFocus"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlock", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RichTextBlock", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RichTextBlock", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RichTextBlock", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RichTextBlock", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RichTextBlock", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RichTextBlock", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlock", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlock", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlock", "PointerExited"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlock", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlock", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlock", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlock", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlock", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichTextBlock", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichTextBlock", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlock", "RightTapped"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RichTextBlock", "Tapped"): ("Microsoft.UI.Xaml.Controls.RichTextBlock", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Windows.Foundation.IInspectable"),
    ("_:RichTextBlockOverflow", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:RichTextBlockOverflow", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:RichTextBlockOverflow", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Windows.Foundation.IInspectable"),
    ("_:RichTextBlockOverflow", "Loaded"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlockOverflow", "Loading"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Windows.Foundation.IInspectable"),
    ("_:RichTextBlockOverflow", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:RichTextBlockOverflow", "Unloaded"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlockOverflow", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RichTextBlockOverflow", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RichTextBlockOverflow", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RichTextBlockOverflow", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:RichTextBlockOverflow", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlockOverflow", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RichTextBlockOverflow", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "DragEnter"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichTextBlockOverflow", "DragLeave"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichTextBlockOverflow", "DragOver"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichTextBlockOverflow", "DragStarting"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:RichTextBlockOverflow", "Drop"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:RichTextBlockOverflow", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:RichTextBlockOverflow", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RichTextBlockOverflow", "GotFocus"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlockOverflow", "Holding"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RichTextBlockOverflow", "KeyDown"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "KeyUp"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RichTextBlockOverflow", "LostFocus"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlockOverflow", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RichTextBlockOverflow", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "PointerExited"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RichTextBlockOverflow", "RightTapped"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RichTextBlockOverflow", "Tapped"): ("Microsoft.UI.Xaml.Controls.RichTextBlockOverflow", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Slider", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Slider", "Windows.Foundation.IInspectable"),
    ("_:Slider", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Slider", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Slider", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Slider", "Windows.Foundation.IInspectable"),
    ("_:Slider", "Loaded"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Slider", "Loading"): ("Microsoft.UI.Xaml.Controls.Slider", "Windows.Foundation.IInspectable"),
    ("_:Slider", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Slider", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Slider", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Slider", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Slider", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Slider", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Slider", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Slider", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Slider", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Slider", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Slider", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Slider", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Slider", "DragOver"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Slider", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Slider", "Drop"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Slider", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Slider", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Slider", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Slider", "Holding"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Slider", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Slider", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Slider", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Slider", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Slider", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Slider", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Slider", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Slider", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Slider", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Slider", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Slider", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Slider", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Slider", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Slider", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Slider", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Slider", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Slider", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Slider", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Slider", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Slider", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Slider", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Slider", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Slider", "Tapped"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Slider", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:Slider", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:Slider", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Slider", "ValueChanged"): ("Microsoft.UI.Xaml.Controls.Slider", "Microsoft.UI.Xaml.Controls.RangeBaseValueChangedEventArgs"),
    ("_:SplitButton", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Windows.Foundation.IInspectable"),
    ("_:SplitButton", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:SplitButton", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:SplitButton", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Windows.Foundation.IInspectable"),
    ("_:SplitButton", "Loaded"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitButton", "Loading"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Windows.Foundation.IInspectable"),
    ("_:SplitButton", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:SplitButton", "Unloaded"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitButton", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:SplitButton", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:SplitButton", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:SplitButton", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:SplitButton", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:SplitButton", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitButton", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:SplitButton", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:SplitButton", "DragEnter"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SplitButton", "DragLeave"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SplitButton", "DragOver"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SplitButton", "DragStarting"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:SplitButton", "Drop"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SplitButton", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:SplitButton", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:SplitButton", "GotFocus"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitButton", "Holding"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:SplitButton", "KeyDown"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SplitButton", "KeyUp"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SplitButton", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:SplitButton", "LostFocus"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitButton", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:SplitButton", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:SplitButton", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:SplitButton", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:SplitButton", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:SplitButton", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:SplitButton", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitButton", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitButton", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitButton", "PointerExited"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitButton", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitButton", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitButton", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitButton", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitButton", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SplitButton", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SplitButton", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitButton", "RightTapped"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:SplitButton", "Tapped"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:SplitButton", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:SplitButton", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:SplitButton", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.SplitButton", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:SplitView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.SplitView", "Windows.Foundation.IInspectable"),
    ("_:SplitView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:SplitView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:SplitView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.SplitView", "Windows.Foundation.IInspectable"),
    ("_:SplitView", "Loaded"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitView", "Loading"): ("Microsoft.UI.Xaml.Controls.SplitView", "Windows.Foundation.IInspectable"),
    ("_:SplitView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:SplitView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:SplitView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:SplitView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:SplitView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:SplitView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:SplitView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:SplitView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:SplitView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SplitView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SplitView", "DragOver"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SplitView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:SplitView", "Drop"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SplitView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:SplitView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:SplitView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitView", "Holding"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:SplitView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SplitView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SplitView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:SplitView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:SplitView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:SplitView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:SplitView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:SplitView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:SplitView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:SplitView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SplitView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SplitView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SplitView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SplitView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:SplitView", "Tapped"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:SplitView", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:SplitView", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:SplitView", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.SplitView", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:StackPanel", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Windows.Foundation.IInspectable"),
    ("_:StackPanel", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:StackPanel", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:StackPanel", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Windows.Foundation.IInspectable"),
    ("_:StackPanel", "Loaded"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:StackPanel", "Loading"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Windows.Foundation.IInspectable"),
    ("_:StackPanel", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:StackPanel", "Unloaded"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:StackPanel", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:StackPanel", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:StackPanel", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:StackPanel", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:StackPanel", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:StackPanel", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:StackPanel", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:StackPanel", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:StackPanel", "DragEnter"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:StackPanel", "DragLeave"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:StackPanel", "DragOver"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:StackPanel", "DragStarting"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:StackPanel", "Drop"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:StackPanel", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:StackPanel", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:StackPanel", "GotFocus"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:StackPanel", "Holding"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:StackPanel", "KeyDown"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:StackPanel", "KeyUp"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:StackPanel", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:StackPanel", "LostFocus"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:StackPanel", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:StackPanel", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:StackPanel", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:StackPanel", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:StackPanel", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:StackPanel", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:StackPanel", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:StackPanel", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:StackPanel", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:StackPanel", "PointerExited"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:StackPanel", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:StackPanel", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:StackPanel", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:StackPanel", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:StackPanel", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:StackPanel", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:StackPanel", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:StackPanel", "RightTapped"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:StackPanel", "Tapped"): ("Microsoft.UI.Xaml.Controls.StackPanel", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:SwapChainPanel", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Windows.Foundation.IInspectable"),
    ("_:SwapChainPanel", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:SwapChainPanel", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:SwapChainPanel", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Windows.Foundation.IInspectable"),
    ("_:SwapChainPanel", "Loaded"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwapChainPanel", "Loading"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Windows.Foundation.IInspectable"),
    ("_:SwapChainPanel", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:SwapChainPanel", "Unloaded"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwapChainPanel", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:SwapChainPanel", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:SwapChainPanel", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:SwapChainPanel", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:SwapChainPanel", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:SwapChainPanel", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwapChainPanel", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:SwapChainPanel", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:SwapChainPanel", "DragEnter"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SwapChainPanel", "DragLeave"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SwapChainPanel", "DragOver"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SwapChainPanel", "DragStarting"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:SwapChainPanel", "Drop"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SwapChainPanel", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:SwapChainPanel", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:SwapChainPanel", "GotFocus"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwapChainPanel", "Holding"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:SwapChainPanel", "KeyDown"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SwapChainPanel", "KeyUp"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SwapChainPanel", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:SwapChainPanel", "LostFocus"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwapChainPanel", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:SwapChainPanel", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:SwapChainPanel", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:SwapChainPanel", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:SwapChainPanel", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:SwapChainPanel", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:SwapChainPanel", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwapChainPanel", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwapChainPanel", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwapChainPanel", "PointerExited"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwapChainPanel", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwapChainPanel", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwapChainPanel", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwapChainPanel", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwapChainPanel", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SwapChainPanel", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SwapChainPanel", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwapChainPanel", "RightTapped"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:SwapChainPanel", "Tapped"): ("Microsoft.UI.Xaml.Controls.SwapChainPanel", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:SwipeControl", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Windows.Foundation.IInspectable"),
    ("_:SwipeControl", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:SwipeControl", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:SwipeControl", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Windows.Foundation.IInspectable"),
    ("_:SwipeControl", "Loaded"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwipeControl", "Loading"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Windows.Foundation.IInspectable"),
    ("_:SwipeControl", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:SwipeControl", "Unloaded"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwipeControl", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:SwipeControl", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:SwipeControl", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:SwipeControl", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:SwipeControl", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:SwipeControl", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwipeControl", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:SwipeControl", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:SwipeControl", "DragEnter"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SwipeControl", "DragLeave"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SwipeControl", "DragOver"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SwipeControl", "DragStarting"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:SwipeControl", "Drop"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SwipeControl", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:SwipeControl", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:SwipeControl", "GotFocus"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwipeControl", "Holding"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:SwipeControl", "KeyDown"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SwipeControl", "KeyUp"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SwipeControl", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:SwipeControl", "LostFocus"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwipeControl", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:SwipeControl", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:SwipeControl", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:SwipeControl", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:SwipeControl", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:SwipeControl", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:SwipeControl", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwipeControl", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwipeControl", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwipeControl", "PointerExited"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwipeControl", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwipeControl", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwipeControl", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwipeControl", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SwipeControl", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SwipeControl", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SwipeControl", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SwipeControl", "RightTapped"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:SwipeControl", "Tapped"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:SwipeControl", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:SwipeControl", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:SwipeControl", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.SwipeControl", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:SymbolIcon", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Windows.Foundation.IInspectable"),
    ("_:SymbolIcon", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:SymbolIcon", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:SymbolIcon", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Windows.Foundation.IInspectable"),
    ("_:SymbolIcon", "Loaded"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SymbolIcon", "Loading"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Windows.Foundation.IInspectable"),
    ("_:SymbolIcon", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:SymbolIcon", "Unloaded"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SymbolIcon", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:SymbolIcon", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:SymbolIcon", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:SymbolIcon", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:SymbolIcon", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:SymbolIcon", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SymbolIcon", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:SymbolIcon", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:SymbolIcon", "DragEnter"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SymbolIcon", "DragLeave"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SymbolIcon", "DragOver"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SymbolIcon", "DragStarting"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:SymbolIcon", "Drop"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:SymbolIcon", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:SymbolIcon", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:SymbolIcon", "GotFocus"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SymbolIcon", "Holding"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:SymbolIcon", "KeyDown"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SymbolIcon", "KeyUp"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SymbolIcon", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:SymbolIcon", "LostFocus"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SymbolIcon", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:SymbolIcon", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:SymbolIcon", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:SymbolIcon", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:SymbolIcon", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:SymbolIcon", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:SymbolIcon", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SymbolIcon", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SymbolIcon", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SymbolIcon", "PointerExited"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SymbolIcon", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SymbolIcon", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SymbolIcon", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SymbolIcon", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SymbolIcon", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SymbolIcon", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SymbolIcon", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SymbolIcon", "RightTapped"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:SymbolIcon", "Tapped"): ("Microsoft.UI.Xaml.Controls.SymbolIcon", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TabView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.TabView", "Windows.Foundation.IInspectable"),
    ("_:TabView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:TabView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:TabView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.TabView", "Windows.Foundation.IInspectable"),
    ("_:TabView", "Loaded"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabView", "Loading"): ("Microsoft.UI.Xaml.Controls.TabView", "Windows.Foundation.IInspectable"),
    ("_:TabView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:TabView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:TabView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:TabView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:TabView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:TabView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:TabView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:TabView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:TabView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TabView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TabView", "DragOver"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TabView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:TabView", "Drop"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TabView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:TabView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:TabView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabView", "Holding"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:TabView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TabView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TabView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:TabView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:TabView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:TabView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:TabView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:TabView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:TabView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:TabView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TabView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TabView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:TabView", "Tapped"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TabView", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:TabView", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:TabView", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.TabView", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:TabViewItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Windows.Foundation.IInspectable"),
    ("_:TabViewItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:TabViewItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:TabViewItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Windows.Foundation.IInspectable"),
    ("_:TabViewItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabViewItem", "Loading"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Windows.Foundation.IInspectable"),
    ("_:TabViewItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:TabViewItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabViewItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:TabViewItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:TabViewItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:TabViewItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:TabViewItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:TabViewItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabViewItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:TabViewItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:TabViewItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TabViewItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TabViewItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TabViewItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:TabViewItem", "Drop"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TabViewItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:TabViewItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:TabViewItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabViewItem", "Holding"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:TabViewItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TabViewItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TabViewItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:TabViewItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabViewItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:TabViewItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:TabViewItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:TabViewItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:TabViewItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:TabViewItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:TabViewItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabViewItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabViewItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabViewItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabViewItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabViewItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabViewItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabViewItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TabViewItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TabViewItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TabViewItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TabViewItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:TabViewItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TabViewItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:TabViewItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:TabViewItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.TabViewItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:TeachingTip", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Windows.Foundation.IInspectable"),
    ("_:TeachingTip", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:TeachingTip", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:TeachingTip", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Windows.Foundation.IInspectable"),
    ("_:TeachingTip", "Loaded"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TeachingTip", "Loading"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Windows.Foundation.IInspectable"),
    ("_:TeachingTip", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:TeachingTip", "Unloaded"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TeachingTip", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:TeachingTip", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:TeachingTip", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:TeachingTip", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:TeachingTip", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:TeachingTip", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TeachingTip", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:TeachingTip", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:TeachingTip", "DragEnter"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TeachingTip", "DragLeave"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TeachingTip", "DragOver"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TeachingTip", "DragStarting"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:TeachingTip", "Drop"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TeachingTip", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:TeachingTip", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:TeachingTip", "GotFocus"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TeachingTip", "Holding"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:TeachingTip", "KeyDown"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TeachingTip", "KeyUp"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TeachingTip", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:TeachingTip", "LostFocus"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TeachingTip", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:TeachingTip", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:TeachingTip", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:TeachingTip", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:TeachingTip", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:TeachingTip", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:TeachingTip", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TeachingTip", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TeachingTip", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TeachingTip", "PointerExited"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TeachingTip", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TeachingTip", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TeachingTip", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TeachingTip", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TeachingTip", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TeachingTip", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TeachingTip", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TeachingTip", "RightTapped"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:TeachingTip", "Tapped"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TeachingTip", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:TeachingTip", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:TeachingTip", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.TeachingTip", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:TextBlock", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Windows.Foundation.IInspectable"),
    ("_:TextBlock", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:TextBlock", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:TextBlock", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Windows.Foundation.IInspectable"),
    ("_:TextBlock", "Loaded"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBlock", "Loading"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Windows.Foundation.IInspectable"),
    ("_:TextBlock", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:TextBlock", "Unloaded"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBlock", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:TextBlock", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:TextBlock", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:TextBlock", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:TextBlock", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:TextBlock", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBlock", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:TextBlock", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:TextBlock", "DragEnter"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TextBlock", "DragLeave"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TextBlock", "DragOver"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TextBlock", "DragStarting"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:TextBlock", "Drop"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TextBlock", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:TextBlock", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:TextBlock", "GotFocus"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBlock", "Holding"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:TextBlock", "KeyDown"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TextBlock", "KeyUp"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TextBlock", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:TextBlock", "LostFocus"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBlock", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:TextBlock", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:TextBlock", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:TextBlock", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:TextBlock", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:TextBlock", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:TextBlock", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBlock", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBlock", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBlock", "PointerExited"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBlock", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBlock", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBlock", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBlock", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBlock", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TextBlock", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TextBlock", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBlock", "RightTapped"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:TextBlock", "Tapped"): ("Microsoft.UI.Xaml.Controls.TextBlock", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TextBox", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.TextBox", "Windows.Foundation.IInspectable"),
    ("_:TextBox", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:TextBox", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:TextBox", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.TextBox", "Windows.Foundation.IInspectable"),
    ("_:TextBox", "Loaded"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBox", "Loading"): ("Microsoft.UI.Xaml.Controls.TextBox", "Windows.Foundation.IInspectable"),
    ("_:TextBox", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:TextBox", "Unloaded"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBox", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:TextBox", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:TextBox", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:TextBox", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:TextBox", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:TextBox", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBox", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:TextBox", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:TextBox", "DragEnter"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TextBox", "DragLeave"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TextBox", "DragOver"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TextBox", "DragStarting"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:TextBox", "Drop"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TextBox", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:TextBox", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:TextBox", "GotFocus"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBox", "Holding"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:TextBox", "KeyDown"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TextBox", "KeyUp"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TextBox", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:TextBox", "LostFocus"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBox", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:TextBox", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:TextBox", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:TextBox", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:TextBox", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:TextBox", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:TextBox", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBox", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBox", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBox", "PointerExited"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBox", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBox", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBox", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBox", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TextBox", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TextBox", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TextBox", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TextBox", "RightTapped"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:TextBox", "Tapped"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TextBox", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:TextBox", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:TextBox", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.TextBox", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:TimePicker", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Windows.Foundation.IInspectable"),
    ("_:TimePicker", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:TimePicker", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:TimePicker", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Windows.Foundation.IInspectable"),
    ("_:TimePicker", "Loaded"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TimePicker", "Loading"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Windows.Foundation.IInspectable"),
    ("_:TimePicker", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:TimePicker", "Unloaded"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TimePicker", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:TimePicker", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:TimePicker", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:TimePicker", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:TimePicker", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:TimePicker", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TimePicker", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:TimePicker", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:TimePicker", "DragEnter"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TimePicker", "DragLeave"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TimePicker", "DragOver"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TimePicker", "DragStarting"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:TimePicker", "Drop"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TimePicker", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:TimePicker", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:TimePicker", "GotFocus"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TimePicker", "Holding"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:TimePicker", "KeyDown"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TimePicker", "KeyUp"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TimePicker", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:TimePicker", "LostFocus"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TimePicker", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:TimePicker", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:TimePicker", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:TimePicker", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:TimePicker", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:TimePicker", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:TimePicker", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TimePicker", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TimePicker", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TimePicker", "PointerExited"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TimePicker", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TimePicker", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TimePicker", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TimePicker", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TimePicker", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TimePicker", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TimePicker", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TimePicker", "RightTapped"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:TimePicker", "Tapped"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TimePicker", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:TimePicker", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:TimePicker", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.TimePicker", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ToggleSplitButton", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Windows.Foundation.IInspectable"),
    ("_:ToggleSplitButton", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ToggleSplitButton", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ToggleSplitButton", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Windows.Foundation.IInspectable"),
    ("_:ToggleSplitButton", "Loaded"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSplitButton", "Loading"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Windows.Foundation.IInspectable"),
    ("_:ToggleSplitButton", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ToggleSplitButton", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSplitButton", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ToggleSplitButton", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ToggleSplitButton", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ToggleSplitButton", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ToggleSplitButton", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ToggleSplitButton", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSplitButton", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ToggleSplitButton", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ToggleSplitButton", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToggleSplitButton", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToggleSplitButton", "DragOver"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToggleSplitButton", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ToggleSplitButton", "Drop"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToggleSplitButton", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ToggleSplitButton", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ToggleSplitButton", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSplitButton", "Holding"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ToggleSplitButton", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleSplitButton", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleSplitButton", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ToggleSplitButton", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSplitButton", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ToggleSplitButton", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ToggleSplitButton", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ToggleSplitButton", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ToggleSplitButton", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ToggleSplitButton", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ToggleSplitButton", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSplitButton", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSplitButton", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSplitButton", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSplitButton", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSplitButton", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSplitButton", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSplitButton", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSplitButton", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleSplitButton", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleSplitButton", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSplitButton", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ToggleSplitButton", "Tapped"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ToggleSplitButton", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ToggleSplitButton", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ToggleSplitButton", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSplitButton", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ToggleSwitch", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Windows.Foundation.IInspectable"),
    ("_:ToggleSwitch", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ToggleSwitch", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ToggleSwitch", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Windows.Foundation.IInspectable"),
    ("_:ToggleSwitch", "Loaded"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSwitch", "Loading"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Windows.Foundation.IInspectable"),
    ("_:ToggleSwitch", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ToggleSwitch", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSwitch", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ToggleSwitch", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ToggleSwitch", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ToggleSwitch", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ToggleSwitch", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ToggleSwitch", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSwitch", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ToggleSwitch", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ToggleSwitch", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToggleSwitch", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToggleSwitch", "DragOver"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToggleSwitch", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ToggleSwitch", "Drop"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToggleSwitch", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ToggleSwitch", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ToggleSwitch", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSwitch", "Holding"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ToggleSwitch", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleSwitch", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleSwitch", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ToggleSwitch", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSwitch", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ToggleSwitch", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ToggleSwitch", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ToggleSwitch", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ToggleSwitch", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ToggleSwitch", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ToggleSwitch", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSwitch", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSwitch", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSwitch", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSwitch", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSwitch", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSwitch", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSwitch", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleSwitch", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleSwitch", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleSwitch", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleSwitch", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ToggleSwitch", "Tapped"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ToggleSwitch", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ToggleSwitch", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ToggleSwitch", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ToggleSwitch", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ToolTip", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Windows.Foundation.IInspectable"),
    ("_:ToolTip", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:ToolTip", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:ToolTip", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Windows.Foundation.IInspectable"),
    ("_:ToolTip", "Loaded"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToolTip", "Loading"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Windows.Foundation.IInspectable"),
    ("_:ToolTip", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:ToolTip", "Unloaded"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToolTip", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ToolTip", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ToolTip", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ToolTip", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:ToolTip", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ToolTip", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToolTip", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ToolTip", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ToolTip", "DragEnter"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToolTip", "DragLeave"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToolTip", "DragOver"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToolTip", "DragStarting"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:ToolTip", "Drop"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:ToolTip", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:ToolTip", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ToolTip", "GotFocus"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToolTip", "Holding"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ToolTip", "KeyDown"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToolTip", "KeyUp"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToolTip", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ToolTip", "LostFocus"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToolTip", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ToolTip", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ToolTip", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ToolTip", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ToolTip", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ToolTip", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ToolTip", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToolTip", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToolTip", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToolTip", "PointerExited"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToolTip", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToolTip", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToolTip", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToolTip", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToolTip", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToolTip", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToolTip", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToolTip", "RightTapped"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ToolTip", "Tapped"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ToolTip", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:ToolTip", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:ToolTip", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.ToolTip", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:TreeView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.TreeView", "Windows.Foundation.IInspectable"),
    ("_:TreeView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:TreeView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:TreeView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.TreeView", "Windows.Foundation.IInspectable"),
    ("_:TreeView", "Loaded"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeView", "Loading"): ("Microsoft.UI.Xaml.Controls.TreeView", "Windows.Foundation.IInspectable"),
    ("_:TreeView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:TreeView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:TreeView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:TreeView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:TreeView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:TreeView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:TreeView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:TreeView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:TreeView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeView", "DragOver"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:TreeView", "Drop"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:TreeView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:TreeView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeView", "Holding"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:TreeView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:TreeView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:TreeView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:TreeView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:TreeView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:TreeView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:TreeView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:TreeView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:TreeView", "Tapped"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TreeView", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:TreeView", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:TreeView", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.TreeView", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:TreeViewItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Windows.Foundation.IInspectable"),
    ("_:TreeViewItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:TreeViewItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:TreeViewItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Windows.Foundation.IInspectable"),
    ("_:TreeViewItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewItem", "Loading"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Windows.Foundation.IInspectable"),
    ("_:TreeViewItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:TreeViewItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:TreeViewItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:TreeViewItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:TreeViewItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:TreeViewItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:TreeViewItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:TreeViewItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:TreeViewItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeViewItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeViewItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeViewItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:TreeViewItem", "Drop"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeViewItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:TreeViewItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:TreeViewItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewItem", "Holding"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:TreeViewItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeViewItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeViewItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:TreeViewItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:TreeViewItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:TreeViewItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:TreeViewItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:TreeViewItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:TreeViewItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:TreeViewItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeViewItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeViewItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:TreeViewItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TreeViewItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:TreeViewItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:TreeViewItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:TreeViewList", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Windows.Foundation.IInspectable"),
    ("_:TreeViewList", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:TreeViewList", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:TreeViewList", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Windows.Foundation.IInspectable"),
    ("_:TreeViewList", "Loaded"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewList", "Loading"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Windows.Foundation.IInspectable"),
    ("_:TreeViewList", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:TreeViewList", "Unloaded"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewList", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:TreeViewList", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:TreeViewList", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:TreeViewList", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:TreeViewList", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:TreeViewList", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewList", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:TreeViewList", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:TreeViewList", "DragEnter"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeViewList", "DragLeave"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeViewList", "DragOver"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeViewList", "DragStarting"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:TreeViewList", "Drop"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TreeViewList", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:TreeViewList", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:TreeViewList", "GotFocus"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewList", "Holding"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:TreeViewList", "KeyDown"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeViewList", "KeyUp"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeViewList", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:TreeViewList", "LostFocus"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewList", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:TreeViewList", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:TreeViewList", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:TreeViewList", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:TreeViewList", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:TreeViewList", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:TreeViewList", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewList", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewList", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewList", "PointerExited"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewList", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewList", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewList", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewList", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TreeViewList", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeViewList", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TreeViewList", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TreeViewList", "RightTapped"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:TreeViewList", "Tapped"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TreeViewList", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:TreeViewList", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:TreeViewList", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:TreeViewList", "DragItemsCompleted"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.DragItemsCompletedEventArgs"),
    ("_:TreeViewList", "DragItemsStarting"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.DragItemsStartingEventArgs"),
    ("_:TreeViewList", "ItemClick"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.ItemClickEventArgs"),
    ("_:TreeViewList", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.TreeViewList", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:TwoPaneView", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Windows.Foundation.IInspectable"),
    ("_:TwoPaneView", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:TwoPaneView", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:TwoPaneView", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Windows.Foundation.IInspectable"),
    ("_:TwoPaneView", "Loaded"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TwoPaneView", "Loading"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Windows.Foundation.IInspectable"),
    ("_:TwoPaneView", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:TwoPaneView", "Unloaded"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TwoPaneView", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:TwoPaneView", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:TwoPaneView", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:TwoPaneView", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:TwoPaneView", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:TwoPaneView", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TwoPaneView", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:TwoPaneView", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:TwoPaneView", "DragEnter"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TwoPaneView", "DragLeave"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TwoPaneView", "DragOver"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TwoPaneView", "DragStarting"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:TwoPaneView", "Drop"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:TwoPaneView", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:TwoPaneView", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:TwoPaneView", "GotFocus"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TwoPaneView", "Holding"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:TwoPaneView", "KeyDown"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TwoPaneView", "KeyUp"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TwoPaneView", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:TwoPaneView", "LostFocus"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TwoPaneView", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:TwoPaneView", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:TwoPaneView", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:TwoPaneView", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:TwoPaneView", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:TwoPaneView", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:TwoPaneView", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TwoPaneView", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TwoPaneView", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TwoPaneView", "PointerExited"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TwoPaneView", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TwoPaneView", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TwoPaneView", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TwoPaneView", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:TwoPaneView", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TwoPaneView", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:TwoPaneView", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:TwoPaneView", "RightTapped"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:TwoPaneView", "Tapped"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:TwoPaneView", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs"),
    ("_:TwoPaneView", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs"),
    ("_:TwoPaneView", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.TwoPaneView", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:VariableSizedWrapGrid", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Windows.Foundation.IInspectable"),
    ("_:VariableSizedWrapGrid", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:VariableSizedWrapGrid", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:VariableSizedWrapGrid", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Windows.Foundation.IInspectable"),
    ("_:VariableSizedWrapGrid", "Loaded"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "Loading"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Windows.Foundation.IInspectable"),
    ("_:VariableSizedWrapGrid", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:VariableSizedWrapGrid", "Unloaded"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:VariableSizedWrapGrid", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:VariableSizedWrapGrid", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:VariableSizedWrapGrid", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:VariableSizedWrapGrid", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:VariableSizedWrapGrid", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "DragEnter"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:VariableSizedWrapGrid", "DragLeave"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:VariableSizedWrapGrid", "DragOver"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:VariableSizedWrapGrid", "DragStarting"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:VariableSizedWrapGrid", "Drop"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:VariableSizedWrapGrid", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:VariableSizedWrapGrid", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:VariableSizedWrapGrid", "GotFocus"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "Holding"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:VariableSizedWrapGrid", "KeyDown"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "KeyUp"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:VariableSizedWrapGrid", "LostFocus"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:VariableSizedWrapGrid", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "PointerExited"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "RightTapped"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:VariableSizedWrapGrid", "Tapped"): ("Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Viewbox", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Windows.Foundation.IInspectable"),
    ("_:Viewbox", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:Viewbox", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:Viewbox", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Windows.Foundation.IInspectable"),
    ("_:Viewbox", "Loaded"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Viewbox", "Loading"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Windows.Foundation.IInspectable"),
    ("_:Viewbox", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:Viewbox", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Viewbox", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Viewbox", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Viewbox", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Viewbox", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:Viewbox", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Viewbox", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Viewbox", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Viewbox", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Viewbox", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Viewbox", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Viewbox", "DragOver"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Viewbox", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:Viewbox", "Drop"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:Viewbox", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:Viewbox", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Viewbox", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Viewbox", "Holding"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Viewbox", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Viewbox", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Viewbox", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Viewbox", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Viewbox", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Viewbox", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Viewbox", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Viewbox", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Viewbox", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Viewbox", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Viewbox", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Viewbox", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Viewbox", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Viewbox", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Viewbox", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Viewbox", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Viewbox", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Viewbox", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Viewbox", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Viewbox", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Viewbox", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Viewbox", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Viewbox", "Tapped"): ("Microsoft.UI.Xaml.Controls.Viewbox", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:VirtualizingPanel", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Windows.Foundation.IInspectable"),
    ("_:VirtualizingPanel", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:VirtualizingPanel", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:VirtualizingPanel", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Windows.Foundation.IInspectable"),
    ("_:VirtualizingPanel", "Loaded"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VirtualizingPanel", "Loading"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Windows.Foundation.IInspectable"),
    ("_:VirtualizingPanel", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:VirtualizingPanel", "Unloaded"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VirtualizingPanel", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:VirtualizingPanel", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:VirtualizingPanel", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:VirtualizingPanel", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:VirtualizingPanel", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:VirtualizingPanel", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VirtualizingPanel", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:VirtualizingPanel", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:VirtualizingPanel", "DragEnter"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:VirtualizingPanel", "DragLeave"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:VirtualizingPanel", "DragOver"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:VirtualizingPanel", "DragStarting"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:VirtualizingPanel", "Drop"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:VirtualizingPanel", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:VirtualizingPanel", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:VirtualizingPanel", "GotFocus"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VirtualizingPanel", "Holding"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:VirtualizingPanel", "KeyDown"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:VirtualizingPanel", "KeyUp"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:VirtualizingPanel", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:VirtualizingPanel", "LostFocus"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VirtualizingPanel", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:VirtualizingPanel", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:VirtualizingPanel", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:VirtualizingPanel", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:VirtualizingPanel", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:VirtualizingPanel", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:VirtualizingPanel", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VirtualizingPanel", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VirtualizingPanel", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VirtualizingPanel", "PointerExited"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VirtualizingPanel", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VirtualizingPanel", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VirtualizingPanel", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VirtualizingPanel", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:VirtualizingPanel", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:VirtualizingPanel", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:VirtualizingPanel", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:VirtualizingPanel", "RightTapped"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:VirtualizingPanel", "Tapped"): ("Microsoft.UI.Xaml.Controls.VirtualizingPanel", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:WebView2", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.WebView2", "Windows.Foundation.IInspectable"),
    ("_:WebView2", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:WebView2", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:WebView2", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.WebView2", "Windows.Foundation.IInspectable"),
    ("_:WebView2", "Loaded"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WebView2", "Loading"): ("Microsoft.UI.Xaml.Controls.WebView2", "Windows.Foundation.IInspectable"),
    ("_:WebView2", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:WebView2", "Unloaded"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WebView2", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:WebView2", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:WebView2", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:WebView2", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:WebView2", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:WebView2", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WebView2", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:WebView2", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:WebView2", "DragEnter"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:WebView2", "DragLeave"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:WebView2", "DragOver"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:WebView2", "DragStarting"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:WebView2", "Drop"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:WebView2", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:WebView2", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:WebView2", "GotFocus"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WebView2", "Holding"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:WebView2", "KeyDown"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:WebView2", "KeyUp"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:WebView2", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:WebView2", "LostFocus"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WebView2", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:WebView2", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:WebView2", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:WebView2", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:WebView2", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:WebView2", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:WebView2", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WebView2", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WebView2", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WebView2", "PointerExited"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WebView2", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WebView2", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WebView2", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WebView2", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WebView2", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:WebView2", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:WebView2", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WebView2", "RightTapped"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:WebView2", "Tapped"): ("Microsoft.UI.Xaml.Controls.WebView2", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:WrapGrid", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Windows.Foundation.IInspectable"),
    ("_:WrapGrid", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Controls.DataContextChangedEventArgs"),
    ("_:WrapGrid", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Controls.EffectiveViewportChangedEventArgs"),
    ("_:WrapGrid", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Windows.Foundation.IInspectable"),
    ("_:WrapGrid", "Loaded"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WrapGrid", "Loading"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Windows.Foundation.IInspectable"),
    ("_:WrapGrid", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Controls.SizeChangedEventHandler"),
    ("_:WrapGrid", "Unloaded"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WrapGrid", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:WrapGrid", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:WrapGrid", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:WrapGrid", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Controls.BringIntoViewRequestedEventArgs"),
    ("_:WrapGrid", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:WrapGrid", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WrapGrid", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:WrapGrid", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:WrapGrid", "DragEnter"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:WrapGrid", "DragLeave"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:WrapGrid", "DragOver"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:WrapGrid", "DragStarting"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Controls.DragStartingEventArgs"),
    ("_:WrapGrid", "Drop"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Controls.DragEventArgs"),
    ("_:WrapGrid", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Controls.DropCompletedEventArgs"),
    ("_:WrapGrid", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:WrapGrid", "GotFocus"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WrapGrid", "Holding"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:WrapGrid", "KeyDown"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:WrapGrid", "KeyUp"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:WrapGrid", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:WrapGrid", "LostFocus"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WrapGrid", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:WrapGrid", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:WrapGrid", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:WrapGrid", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:WrapGrid", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:WrapGrid", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:WrapGrid", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WrapGrid", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WrapGrid", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WrapGrid", "PointerExited"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WrapGrid", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WrapGrid", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WrapGrid", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WrapGrid", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:WrapGrid", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:WrapGrid", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:WrapGrid", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:WrapGrid", "RightTapped"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:WrapGrid", "Tapped"): ("Microsoft.UI.Xaml.Controls.WrapGrid", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ButtonBase", "Click"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ButtonBase", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Windows.Foundation.IInspectable"),
    ("_:ButtonBase", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.DataContextChangedEventArgs"),
    ("_:ButtonBase", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.EffectiveViewportChangedEventArgs"),
    ("_:ButtonBase", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Windows.Foundation.IInspectable"),
    ("_:ButtonBase", "Loaded"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ButtonBase", "Loading"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Windows.Foundation.IInspectable"),
    ("_:ButtonBase", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.SizeChangedEventHandler"),
    ("_:ButtonBase", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ButtonBase", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ButtonBase", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ButtonBase", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ButtonBase", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.BringIntoViewRequestedEventArgs"),
    ("_:ButtonBase", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ButtonBase", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ButtonBase", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ButtonBase", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ButtonBase", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ButtonBase", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ButtonBase", "DragOver"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ButtonBase", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.DragStartingEventArgs"),
    ("_:ButtonBase", "Drop"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ButtonBase", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.DropCompletedEventArgs"),
    ("_:ButtonBase", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ButtonBase", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ButtonBase", "Holding"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ButtonBase", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ButtonBase", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ButtonBase", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ButtonBase", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ButtonBase", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ButtonBase", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ButtonBase", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ButtonBase", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ButtonBase", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ButtonBase", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ButtonBase", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ButtonBase", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ButtonBase", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ButtonBase", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ButtonBase", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ButtonBase", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ButtonBase", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ButtonBase", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ButtonBase", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ButtonBase", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ButtonBase", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ButtonBase", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ButtonBase", "Tapped"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ButtonBase", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.FocusDisengagedEventArgs"),
    ("_:ButtonBase", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.Controls.Primitives.FocusEngagedEventArgs"),
    ("_:ButtonBase", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ButtonBase", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:FlyoutBase", "Closed"): ("Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase", "Windows.Foundation.IInspectable"),
    ("_:FlyoutBase", "Closing"): ("Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase", "Microsoft.UI.Xaml.Controls.Primitives.FlyoutBaseClosingEventArgs"),
    ("_:FlyoutBase", "Opened"): ("Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase", "Windows.Foundation.IInspectable"),
    ("_:FlyoutBase", "Opening"): ("Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase", "Windows.Foundation.IInspectable"),
    ("_:LoopingSelector", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:LoopingSelector", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Windows.Foundation.IInspectable"),
    ("_:LoopingSelector", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.DataContextChangedEventArgs"),
    ("_:LoopingSelector", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.EffectiveViewportChangedEventArgs"),
    ("_:LoopingSelector", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Windows.Foundation.IInspectable"),
    ("_:LoopingSelector", "Loaded"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:LoopingSelector", "Loading"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Windows.Foundation.IInspectable"),
    ("_:LoopingSelector", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.SizeChangedEventHandler"),
    ("_:LoopingSelector", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:LoopingSelector", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:LoopingSelector", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:LoopingSelector", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:LoopingSelector", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.BringIntoViewRequestedEventArgs"),
    ("_:LoopingSelector", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:LoopingSelector", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:LoopingSelector", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:LoopingSelector", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:LoopingSelector", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:LoopingSelector", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:LoopingSelector", "DragOver"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:LoopingSelector", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.DragStartingEventArgs"),
    ("_:LoopingSelector", "Drop"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:LoopingSelector", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.DropCompletedEventArgs"),
    ("_:LoopingSelector", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:LoopingSelector", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:LoopingSelector", "Holding"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:LoopingSelector", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:LoopingSelector", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:LoopingSelector", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:LoopingSelector", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:LoopingSelector", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:LoopingSelector", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:LoopingSelector", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:LoopingSelector", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:LoopingSelector", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:LoopingSelector", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:LoopingSelector", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:LoopingSelector", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:LoopingSelector", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:LoopingSelector", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:LoopingSelector", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:LoopingSelector", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:LoopingSelector", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:LoopingSelector", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:LoopingSelector", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:LoopingSelector", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:LoopingSelector", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:LoopingSelector", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:LoopingSelector", "Tapped"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:LoopingSelector", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.FocusDisengagedEventArgs"),
    ("_:LoopingSelector", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.Controls.Primitives.FocusEngagedEventArgs"),
    ("_:LoopingSelector", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.LoopingSelector", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:RangeBase", "ValueChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.RangeBaseValueChangedEventArgs"),
    ("_:RangeBase", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Windows.Foundation.IInspectable"),
    ("_:RangeBase", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.DataContextChangedEventArgs"),
    ("_:RangeBase", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.EffectiveViewportChangedEventArgs"),
    ("_:RangeBase", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Windows.Foundation.IInspectable"),
    ("_:RangeBase", "Loaded"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RangeBase", "Loading"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Windows.Foundation.IInspectable"),
    ("_:RangeBase", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.SizeChangedEventHandler"),
    ("_:RangeBase", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RangeBase", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:RangeBase", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:RangeBase", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:RangeBase", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.BringIntoViewRequestedEventArgs"),
    ("_:RangeBase", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:RangeBase", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RangeBase", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:RangeBase", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:RangeBase", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:RangeBase", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:RangeBase", "DragOver"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:RangeBase", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.DragStartingEventArgs"),
    ("_:RangeBase", "Drop"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:RangeBase", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.DropCompletedEventArgs"),
    ("_:RangeBase", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:RangeBase", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RangeBase", "Holding"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:RangeBase", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RangeBase", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RangeBase", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:RangeBase", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RangeBase", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:RangeBase", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:RangeBase", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:RangeBase", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:RangeBase", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:RangeBase", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:RangeBase", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RangeBase", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RangeBase", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RangeBase", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RangeBase", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RangeBase", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RangeBase", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RangeBase", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:RangeBase", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RangeBase", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:RangeBase", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:RangeBase", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:RangeBase", "Tapped"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:RangeBase", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.FocusDisengagedEventArgs"),
    ("_:RangeBase", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.Controls.Primitives.FocusEngagedEventArgs"),
    ("_:RangeBase", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.RangeBase", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ScrollBar", "Scroll"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.ScrollEventArgs"),
    ("_:ScrollBar", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Windows.Foundation.IInspectable"),
    ("_:ScrollBar", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.DataContextChangedEventArgs"),
    ("_:ScrollBar", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.EffectiveViewportChangedEventArgs"),
    ("_:ScrollBar", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Windows.Foundation.IInspectable"),
    ("_:ScrollBar", "Loaded"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ScrollBar", "Loading"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Windows.Foundation.IInspectable"),
    ("_:ScrollBar", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.SizeChangedEventHandler"),
    ("_:ScrollBar", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ScrollBar", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ScrollBar", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ScrollBar", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ScrollBar", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.BringIntoViewRequestedEventArgs"),
    ("_:ScrollBar", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ScrollBar", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ScrollBar", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ScrollBar", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ScrollBar", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ScrollBar", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ScrollBar", "DragOver"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ScrollBar", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.DragStartingEventArgs"),
    ("_:ScrollBar", "Drop"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ScrollBar", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.DropCompletedEventArgs"),
    ("_:ScrollBar", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ScrollBar", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ScrollBar", "Holding"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ScrollBar", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ScrollBar", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ScrollBar", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ScrollBar", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ScrollBar", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ScrollBar", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ScrollBar", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ScrollBar", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ScrollBar", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ScrollBar", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ScrollBar", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ScrollBar", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ScrollBar", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ScrollBar", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ScrollBar", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ScrollBar", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ScrollBar", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ScrollBar", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ScrollBar", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ScrollBar", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ScrollBar", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ScrollBar", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ScrollBar", "Tapped"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ScrollBar", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.FocusDisengagedEventArgs"),
    ("_:ScrollBar", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.FocusEngagedEventArgs"),
    ("_:ScrollBar", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ScrollBar", "ValueChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ScrollBar", "Microsoft.UI.Xaml.Controls.Primitives.RangeBaseValueChangedEventArgs"),
    ("_:Selector", "SelectionChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs"),
    ("_:Selector", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Windows.Foundation.IInspectable"),
    ("_:Selector", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.DataContextChangedEventArgs"),
    ("_:Selector", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.EffectiveViewportChangedEventArgs"),
    ("_:Selector", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Windows.Foundation.IInspectable"),
    ("_:Selector", "Loaded"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Selector", "Loading"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Windows.Foundation.IInspectable"),
    ("_:Selector", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.SizeChangedEventHandler"),
    ("_:Selector", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Selector", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Selector", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Selector", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Selector", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.BringIntoViewRequestedEventArgs"),
    ("_:Selector", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Selector", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Selector", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Selector", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Selector", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:Selector", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:Selector", "DragOver"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:Selector", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.DragStartingEventArgs"),
    ("_:Selector", "Drop"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:Selector", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.DropCompletedEventArgs"),
    ("_:Selector", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Selector", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Selector", "Holding"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Selector", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Selector", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Selector", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Selector", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Selector", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Selector", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Selector", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Selector", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Selector", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Selector", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Selector", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Selector", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Selector", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Selector", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Selector", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Selector", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Selector", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Selector", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Selector", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Selector", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Selector", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Selector", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Selector", "Tapped"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Selector", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.FocusDisengagedEventArgs"),
    ("_:Selector", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.Controls.Primitives.FocusEngagedEventArgs"),
    ("_:Selector", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Selector", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:SelectorItem", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Windows.Foundation.IInspectable"),
    ("_:SelectorItem", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.DataContextChangedEventArgs"),
    ("_:SelectorItem", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.EffectiveViewportChangedEventArgs"),
    ("_:SelectorItem", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Windows.Foundation.IInspectable"),
    ("_:SelectorItem", "Loaded"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SelectorItem", "Loading"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Windows.Foundation.IInspectable"),
    ("_:SelectorItem", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.SizeChangedEventHandler"),
    ("_:SelectorItem", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SelectorItem", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:SelectorItem", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:SelectorItem", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:SelectorItem", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.BringIntoViewRequestedEventArgs"),
    ("_:SelectorItem", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:SelectorItem", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SelectorItem", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:SelectorItem", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:SelectorItem", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:SelectorItem", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:SelectorItem", "DragOver"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:SelectorItem", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.DragStartingEventArgs"),
    ("_:SelectorItem", "Drop"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:SelectorItem", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.DropCompletedEventArgs"),
    ("_:SelectorItem", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:SelectorItem", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SelectorItem", "Holding"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:SelectorItem", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SelectorItem", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SelectorItem", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:SelectorItem", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SelectorItem", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:SelectorItem", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:SelectorItem", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:SelectorItem", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:SelectorItem", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:SelectorItem", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:SelectorItem", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SelectorItem", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SelectorItem", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SelectorItem", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SelectorItem", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SelectorItem", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SelectorItem", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SelectorItem", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:SelectorItem", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SelectorItem", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:SelectorItem", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:SelectorItem", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:SelectorItem", "Tapped"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:SelectorItem", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.FocusDisengagedEventArgs"),
    ("_:SelectorItem", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.Controls.Primitives.FocusEngagedEventArgs"),
    ("_:SelectorItem", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.SelectorItem", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:Thumb", "DragCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.DragCompletedEventArgs"),
    ("_:Thumb", "DragDelta"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.DragDeltaEventArgs"),
    ("_:Thumb", "DragStarted"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.DragStartedEventArgs"),
    ("_:Thumb", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Windows.Foundation.IInspectable"),
    ("_:Thumb", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.DataContextChangedEventArgs"),
    ("_:Thumb", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.EffectiveViewportChangedEventArgs"),
    ("_:Thumb", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Windows.Foundation.IInspectable"),
    ("_:Thumb", "Loaded"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Thumb", "Loading"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Windows.Foundation.IInspectable"),
    ("_:Thumb", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.SizeChangedEventHandler"),
    ("_:Thumb", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Thumb", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:Thumb", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:Thumb", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:Thumb", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.BringIntoViewRequestedEventArgs"),
    ("_:Thumb", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:Thumb", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Thumb", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:Thumb", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:Thumb", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:Thumb", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:Thumb", "DragOver"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:Thumb", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.DragStartingEventArgs"),
    ("_:Thumb", "Drop"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:Thumb", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.DropCompletedEventArgs"),
    ("_:Thumb", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:Thumb", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Thumb", "Holding"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:Thumb", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Thumb", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Thumb", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:Thumb", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Thumb", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:Thumb", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:Thumb", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:Thumb", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:Thumb", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:Thumb", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:Thumb", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Thumb", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Thumb", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Thumb", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Thumb", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Thumb", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Thumb", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Thumb", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:Thumb", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Thumb", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:Thumb", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:Thumb", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:Thumb", "Tapped"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:Thumb", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.FocusDisengagedEventArgs"),
    ("_:Thumb", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.Controls.Primitives.FocusEngagedEventArgs"),
    ("_:Thumb", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.Thumb", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ToggleButton", "Checked"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleButton", "Indeterminate"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleButton", "Unchecked"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleButton", "ActualThemeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Windows.Foundation.IInspectable"),
    ("_:ToggleButton", "DataContextChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.DataContextChangedEventArgs"),
    ("_:ToggleButton", "EffectiveViewportChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.EffectiveViewportChangedEventArgs"),
    ("_:ToggleButton", "LayoutUpdated"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Windows.Foundation.IInspectable"),
    ("_:ToggleButton", "Loaded"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleButton", "Loading"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Windows.Foundation.IInspectable"),
    ("_:ToggleButton", "SizeChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.SizeChangedEventHandler"),
    ("_:ToggleButton", "Unloaded"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleButton", "AccessKeyDisplayDismissed"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs"),
    ("_:ToggleButton", "AccessKeyDisplayRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs"),
    ("_:ToggleButton", "AccessKeyInvoked"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs"),
    ("_:ToggleButton", "BringIntoViewRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.BringIntoViewRequestedEventArgs"),
    ("_:ToggleButton", "CharacterReceived"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs"),
    ("_:ToggleButton", "ContextCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleButton", "ContextRequested"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.ContextRequestedEventArgs"),
    ("_:ToggleButton", "DoubleTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs"),
    ("_:ToggleButton", "DragEnter"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ToggleButton", "DragLeave"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ToggleButton", "DragOver"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ToggleButton", "DragStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.DragStartingEventArgs"),
    ("_:ToggleButton", "Drop"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.DragEventArgs"),
    ("_:ToggleButton", "DropCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.DropCompletedEventArgs"),
    ("_:ToggleButton", "GettingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.GettingFocusEventArgs"),
    ("_:ToggleButton", "GotFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleButton", "Holding"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.HoldingEventArgs"),
    ("_:ToggleButton", "KeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleButton", "KeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleButton", "LosingFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.LosingFocusEventArgs"),
    ("_:ToggleButton", "LostFocus"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleButton", "ManipulationCompleted"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs"),
    ("_:ToggleButton", "ManipulationDelta"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs"),
    ("_:ToggleButton", "ManipulationInertiaStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs"),
    ("_:ToggleButton", "ManipulationStarted"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs"),
    ("_:ToggleButton", "ManipulationStarting"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs"),
    ("_:ToggleButton", "NoFocusCandidateFound"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.NoFocusCandidateFoundEventArgs"),
    ("_:ToggleButton", "PointerCanceled"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleButton", "PointerCaptureLost"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleButton", "PointerEntered"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleButton", "PointerExited"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleButton", "PointerMoved"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleButton", "PointerPressed"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleButton", "PointerReleased"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleButton", "PointerWheelChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.PointerRoutedEventArgs"),
    ("_:ToggleButton", "PreviewKeyDown"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleButton", "PreviewKeyUp"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.KeyRoutedEventArgs"),
    ("_:ToggleButton", "ProcessKeyboardAccelerators"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
    ("_:ToggleButton", "RightTapped"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs"),
    ("_:ToggleButton", "Tapped"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Input.TappedRoutedEventArgs"),
    ("_:ToggleButton", "FocusDisengaged"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.FocusDisengagedEventArgs"),
    ("_:ToggleButton", "FocusEngaged"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.Controls.Primitives.FocusEngagedEventArgs"),
    ("_:ToggleButton", "IsEnabledChanged"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.DependencyPropertyChangedEventArgs"),
    ("_:ToggleButton", "Click"): ("Microsoft.UI.Xaml.Controls.Primitives.ToggleButton", "Microsoft.UI.Xaml.RoutedEventArgs"),
}

KNOWN_EVENT_NAMES = {k[1] for k in KNOWN_EVENTS}
